# delphix-dct-api
Delphix DCT API

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 3.8.0
- Package version: 13.0.0-rc2
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://support.delphix.com](https://support.delphix.com)

## Requirements.

Python >= 3.6

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import delphix.api.gateway
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import delphix.api.gateway
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import delphix.api.gateway
from pprint import pprint
from delphix.api.gateway.api import accounts_api
from delphix.api.gateway.model.account import Account
from delphix.api.gateway.model.account_create_parameter import AccountCreateParameter
from delphix.api.gateway.model.account_create_response import AccountCreateResponse
from delphix.api.gateway.model.account_update_parameter import AccountUpdateParameter
from delphix.api.gateway.model.change_password_parameter import ChangePasswordParameter
from delphix.api.gateway.model.delete_tag import DeleteTag
from delphix.api.gateway.model.list_accounts_response import ListAccountsResponse
from delphix.api.gateway.model.password_policies_params import PasswordPoliciesParams
from delphix.api.gateway.model.reset_password_parameter import ResetPasswordParameter
from delphix.api.gateway.model.search_accounts_response import SearchAccountsResponse
from delphix.api.gateway.model.search_body import SearchBody
from delphix.api.gateway.model.tags_request import TagsRequest
from delphix.api.gateway.model.tags_response import TagsResponse
# Defining the host is optional and defaults to http://localhost/v3
# See configuration.py for a list of all supported configuration parameters.
configuration = delphix.api.gateway.Configuration(
    host = "http://localhost/v3"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: ApiKeyAuth
configuration.api_key['ApiKeyAuth'] = 'YOUR_API_KEY'

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['ApiKeyAuth'] = 'Bearer'


# Enter a context with an instance of the API client
with delphix.api.gateway.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = accounts_api.AccountsApi(api_client)
    id = 1 # int | Numeric ID of the Account.
change_password_parameter = ChangePasswordParameter(
        old_password="old_password_example",
        new_password="new_password_example",
    ) # ChangePasswordParameter | 

    try:
        # Change Account Password. 
        api_instance.change_account_password(id, change_password_parameter)
    except delphix.api.gateway.ApiException as e:
        print("Exception when calling AccountsApi->change_account_password: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost/v3*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccountsApi* | [**change_account_password**](docs/AccountsApi.md#change_account_password) | **POST** /management/accounts/{id}/change_password | Change Account Password. 
*AccountsApi* | [**create_account**](docs/AccountsApi.md#create_account) | **POST** /management/accounts | Create a new Account 
*AccountsApi* | [**create_account_tags**](docs/AccountsApi.md#create_account_tags) | **POST** /management/accounts/{id}/tags | Create tags for an Account.
*AccountsApi* | [**delete_account**](docs/AccountsApi.md#delete_account) | **DELETE** /management/accounts/{id} | Delete an Account
*AccountsApi* | [**delete_account_tags**](docs/AccountsApi.md#delete_account_tags) | **POST** /management/accounts/{id}/tags/delete | Delete tags for an Account.
*AccountsApi* | [**disable**](docs/AccountsApi.md#disable) | **POST** /management/accounts/{id}/disable | Disable an Account.
*AccountsApi* | [**enable_account**](docs/AccountsApi.md#enable_account) | **POST** /management/accounts/{id}/enable | Enable an Account.
*AccountsApi* | [**get_account**](docs/AccountsApi.md#get_account) | **GET** /management/accounts/{id} | Get an Account by id
*AccountsApi* | [**get_account_tags**](docs/AccountsApi.md#get_account_tags) | **GET** /management/accounts/{id}/tags | Get tags for an Account.
*AccountsApi* | [**get_accounts**](docs/AccountsApi.md#get_accounts) | **GET** /management/accounts | Returns a list of Accounts
*AccountsApi* | [**get_password_policies**](docs/AccountsApi.md#get_password_policies) | **GET** /management/accounts/password-policies | Returns the password policies
*AccountsApi* | [**reset_account_password**](docs/AccountsApi.md#reset_account_password) | **POST** /management/accounts/{id}/reset_password | Reset Account Password. 
*AccountsApi* | [**search_accounts**](docs/AccountsApi.md#search_accounts) | **POST** /management/accounts/search | Search for Accounts.
*AccountsApi* | [**update_account**](docs/AccountsApi.md#update_account) | **PUT** /management/accounts/{id} | Update an Account 
*AccountsApi* | [**update_password_policies**](docs/AccountsApi.md#update_password_policies) | **PATCH** /management/accounts/password-policies | Update password policies.
*AlgorithmsApi* | [**create_algorithm**](docs/AlgorithmsApi.md#create_algorithm) | **POST** /algorithms | Create a new algorithm.
*AlgorithmsApi* | [**create_algorithm_revision**](docs/AlgorithmsApi.md#create_algorithm_revision) | **POST** /algorithms/{algorithmId}/revisions | Create a new algorithm revision.
*AlgorithmsApi* | [**create_algorithm_revision_tags**](docs/AlgorithmsApi.md#create_algorithm_revision_tags) | **POST** /algorithms/{algorithmId}/revisions/{revisionId}/tags | Create tags for an AlgorithmRevision.
*AlgorithmsApi* | [**create_algorithm_tags**](docs/AlgorithmsApi.md#create_algorithm_tags) | **POST** /algorithms/{algorithmId}/tags | Create tags for an Algorithm.
*AlgorithmsApi* | [**delete_algorithm**](docs/AlgorithmsApi.md#delete_algorithm) | **DELETE** /algorithms/{algorithmId} | Delete an algorithm.
*AlgorithmsApi* | [**delete_algorithm_revision**](docs/AlgorithmsApi.md#delete_algorithm_revision) | **DELETE** /algorithms/{algorithmId}/revisions/{revisionId} | Delete an algorithm revision.
*AlgorithmsApi* | [**delete_algorithm_revision_tags**](docs/AlgorithmsApi.md#delete_algorithm_revision_tags) | **POST** /algorithms/{algorithmId}/revisions/{revisionId}/tags/delete | Delete tags for an AlgorithmRevision.
*AlgorithmsApi* | [**delete_algorithm_tags**](docs/AlgorithmsApi.md#delete_algorithm_tags) | **POST** /algorithms/{algorithmId}/tags/delete | Delete tags for an Algorithm.
*AlgorithmsApi* | [**get_algorithm_by_id**](docs/AlgorithmsApi.md#get_algorithm_by_id) | **GET** /algorithms/{algorithmId} | Get an algorithm by ID.
*AlgorithmsApi* | [**get_algorithm_revision_by_id**](docs/AlgorithmsApi.md#get_algorithm_revision_by_id) | **GET** /algorithms/{algorithmId}/revisions/{revisionId} | Retrieve a specific revision of an algorithm.
*AlgorithmsApi* | [**get_algorithm_revision_tags**](docs/AlgorithmsApi.md#get_algorithm_revision_tags) | **GET** /algorithms/{algorithmId}/revisions/{revisionId}/tags | Get tags for an AlgorithmRevision.
*AlgorithmsApi* | [**get_algorithm_revisions**](docs/AlgorithmsApi.md#get_algorithm_revisions) | **GET** /algorithms/{algorithmId}/revisions | Retrieve the list of algorithm revisions for the algorithm.
*AlgorithmsApi* | [**get_algorithm_tags**](docs/AlgorithmsApi.md#get_algorithm_tags) | **GET** /algorithms/{algorithmId}/tags | Get tags for an Algorithm.
*AlgorithmsApi* | [**get_algorithms**](docs/AlgorithmsApi.md#get_algorithms) | **GET** /algorithms | Retrieve the list of algorithms.
*AlgorithmsApi* | [**search_algorithm_revisions**](docs/AlgorithmsApi.md#search_algorithm_revisions) | **POST** /algorithms/{algorithmId}/revisions/search | Search for algorithm revisions.
*AlgorithmsApi* | [**search_algorithms**](docs/AlgorithmsApi.md#search_algorithms) | **POST** /algorithms/search | Search for algorithms.
*AlgorithmsApi* | [**set_algorithm_primary_revision**](docs/AlgorithmsApi.md#set_algorithm_primary_revision) | **POST** /algorithms/{algorithmId}/revisions/{revisionId}/make-primary | Set an algorithm revision to be the primary revision for the algorithm.
*AlgorithmsApi* | [**update_algorithm_revision**](docs/AlgorithmsApi.md#update_algorithm_revision) | **PATCH** /algorithms/{algorithmId}/revisions/{revisionId} | Update an algorithm revision
*AuthorizationApi* | [**add_access_group_account_ids**](docs/AuthorizationApi.md#add_access_group_account_ids) | **POST** /access-groups/{accessGroupId}/account-ids | Add account ids to an Access group
*AuthorizationApi* | [**add_access_group_account_tags**](docs/AuthorizationApi.md#add_access_group_account_tags) | **POST** /access-groups/{accessGroupId}/tags | Add account tags to an Access group
*AuthorizationApi* | [**add_access_group_scopes**](docs/AuthorizationApi.md#add_access_group_scopes) | **POST** /access-groups/{accessGroupId}/scopes | Add scopes to an Access group
*AuthorizationApi* | [**add_always_allowed_permissions**](docs/AuthorizationApi.md#add_always_allowed_permissions) | **POST** /access-groups/{accessGroupId}/scopes/{scopeId}/always_allowed_permissions | Add always allowed permissions for given object type.
*AuthorizationApi* | [**add_objects_to_access_group_scope**](docs/AuthorizationApi.md#add_objects_to_access_group_scope) | **POST** /access-groups/{accessGroupId}/scopes/{scopeId}/objects | Add objects to the access group scope.
*AuthorizationApi* | [**add_role_permissions**](docs/AuthorizationApi.md#add_role_permissions) | **POST** /roles/{roleId}/permissions | Add permissions to a role.
*AuthorizationApi* | [**add_tags_to_scope**](docs/AuthorizationApi.md#add_tags_to_scope) | **POST** /access-groups/{accessGroupId}/scopes/{scopeId}/object-tags | Add object tags to the access group scope.
*AuthorizationApi* | [**create_access_group**](docs/AuthorizationApi.md#create_access_group) | **POST** /access-groups | Create a new access group.
*AuthorizationApi* | [**create_role**](docs/AuthorizationApi.md#create_role) | **POST** /roles | Create custom role
*AuthorizationApi* | [**create_role_tags**](docs/AuthorizationApi.md#create_role_tags) | **POST** /roles/{roleId}/tags | Create tags for a role.
*AuthorizationApi* | [**delete_access_group**](docs/AuthorizationApi.md#delete_access_group) | **DELETE** /access-groups/{accessGroupId} | Delete an Access group.
*AuthorizationApi* | [**delete_access_group_scope_object_tags**](docs/AuthorizationApi.md#delete_access_group_scope_object_tags) | **POST** /access-groups/{accessGroupId}/scopes/{scopeId}/object-tags/delete | Remove tags from the access group scope.
*AuthorizationApi* | [**delete_access_group_scope_objects**](docs/AuthorizationApi.md#delete_access_group_scope_objects) | **POST** /access-groups/{accessGroupId}/scopes/{scopeId}/objects/delete | Remove objects from the access group scope.
*AuthorizationApi* | [**delete_role**](docs/AuthorizationApi.md#delete_role) | **DELETE** /roles/{roleId} | Delete role by ID.
*AuthorizationApi* | [**delete_role_tag**](docs/AuthorizationApi.md#delete_role_tag) | **POST** /roles/{roleId}/tags/delete | Delete tags for a Role.
*AuthorizationApi* | [**get_access_group_by_id**](docs/AuthorizationApi.md#get_access_group_by_id) | **GET** /access-groups/{accessGroupId} | Returns an Access group by ID.
*AuthorizationApi* | [**get_access_group_scope**](docs/AuthorizationApi.md#get_access_group_scope) | **GET** /access-groups/{accessGroupId}/scopes/{scopeId} | Get access group scope.
*AuthorizationApi* | [**get_access_groups**](docs/AuthorizationApi.md#get_access_groups) | **GET** /access-groups | List all access groups.
*AuthorizationApi* | [**get_all_object_permissions**](docs/AuthorizationApi.md#get_all_object_permissions) | **GET** /auth/object-permissions | Returns all of the possible permissions for all of the objects.
*AuthorizationApi* | [**get_object_permissions**](docs/AuthorizationApi.md#get_object_permissions) | **GET** /auth/permissions/objects/{objectType}/{objectId} | Returns permissions for given object.
*AuthorizationApi* | [**get_role_by_id**](docs/AuthorizationApi.md#get_role_by_id) | **GET** /roles/{roleId} | Returns role by ID.
*AuthorizationApi* | [**get_role_tags**](docs/AuthorizationApi.md#get_role_tags) | **GET** /roles/{roleId}/tags | Get tags for a Role.
*AuthorizationApi* | [**get_roles**](docs/AuthorizationApi.md#get_roles) | **GET** /roles | List all roles
*AuthorizationApi* | [**remove_access_group_account_id**](docs/AuthorizationApi.md#remove_access_group_account_id) | **DELETE** /access-groups/{accessGroupId}/account-ids/{accountId} | Remove the account from the access group.
*AuthorizationApi* | [**remove_access_group_account_tags**](docs/AuthorizationApi.md#remove_access_group_account_tags) | **POST** /access-groups/{accessGroupId}/tags/delete | Remove account tags from an access group.
*AuthorizationApi* | [**remove_access_group_scope**](docs/AuthorizationApi.md#remove_access_group_scope) | **DELETE** /access-groups/{accessGroupId}/scopes/{scopeId} | Remove the scope from the Access group.
*AuthorizationApi* | [**remove_always_allowed_permissions**](docs/AuthorizationApi.md#remove_always_allowed_permissions) | **POST** /access-groups/{accessGroupId}/scopes/{scopeId}/always_allowed_permissions/delete | Remove always allowed permissions for given object type.
*AuthorizationApi* | [**remove_role_permissions**](docs/AuthorizationApi.md#remove_role_permissions) | **POST** /roles/{roleId}/permissions/delete | Remove permissions from a role.
*AuthorizationApi* | [**search_access_groups**](docs/AuthorizationApi.md#search_access_groups) | **POST** /access-groups/search | Search for access groups.
*AuthorizationApi* | [**search_roles**](docs/AuthorizationApi.md#search_roles) | **POST** /roles/search | Search for roles.
*AuthorizationApi* | [**update_access_group**](docs/AuthorizationApi.md#update_access_group) | **PATCH** /access-groups/{accessGroupId} | Update an Access group.
*AuthorizationApi* | [**update_access_group_scope**](docs/AuthorizationApi.md#update_access_group_scope) | **PATCH** /access-groups/{accessGroupId}/scopes/{scopeId} | Update access group scope.
*AuthorizationApi* | [**update_role**](docs/AuthorizationApi.md#update_role) | **PATCH** /roles/{roleId} | Update a Role.
*BookmarksApi* | [**create_bookmark**](docs/BookmarksApi.md#create_bookmark) | **POST** /bookmarks | Create a bookmark at the current time.
*BookmarksApi* | [**create_bookmark_tags**](docs/BookmarksApi.md#create_bookmark_tags) | **POST** /bookmarks/{bookmarkId}/tags | Create tags for a Bookmark.
*BookmarksApi* | [**delete_bookmark**](docs/BookmarksApi.md#delete_bookmark) | **DELETE** /bookmarks/{bookmarkId} | Delete a bookmark.
*BookmarksApi* | [**delete_bookmark_tags**](docs/BookmarksApi.md#delete_bookmark_tags) | **POST** /bookmarks/{bookmarkId}/tags/delete | Delete tags for a Bookmark.
*BookmarksApi* | [**get_bookmark_by_id**](docs/BookmarksApi.md#get_bookmark_by_id) | **GET** /bookmarks/{bookmarkId} | Get a bookmark by ID.
*BookmarksApi* | [**get_bookmark_tags**](docs/BookmarksApi.md#get_bookmark_tags) | **GET** /bookmarks/{bookmarkId}/tags | Get tags for a Bookmark.
*BookmarksApi* | [**get_bookmarks**](docs/BookmarksApi.md#get_bookmarks) | **GET** /bookmarks | List all bookmarks.
*BookmarksApi* | [**get_vdb_groups_by_bookmark**](docs/BookmarksApi.md#get_vdb_groups_by_bookmark) | **GET** /bookmarks/{bookmarkId}/vdb-groups | List VDB Groups compatible with this bookmark.
*BookmarksApi* | [**search_bookmarks**](docs/BookmarksApi.md#search_bookmarks) | **POST** /bookmarks/search | Search for bookmarks.
*BookmarksApi* | [**search_vdb_groups_by_bookmark**](docs/BookmarksApi.md#search_vdb_groups_by_bookmark) | **POST** /bookmarks/{bookmarkId}/vdb-groups/search | Search for VDB Groups compatible with this bookmark.
*BookmarksApi* | [**update_bookmark**](docs/BookmarksApi.md#update_bookmark) | **PATCH** /bookmarks/{bookmarkId} | Update a bookmark
*CDBsApi* | [**create_cdb_tags**](docs/CDBsApi.md#create_cdb_tags) | **POST** /cdbs/{cdbId}/tags | Create tags for a CDB.
*CDBsApi* | [**delete_cdb_tags**](docs/CDBsApi.md#delete_cdb_tags) | **POST** /cdbs/{cdbId}/tags/delete | Delete tags for a CDB.
*CDBsApi* | [**get_cdb_by_id**](docs/CDBsApi.md#get_cdb_by_id) | **GET** /cdbs/{cdbId} | Get a CDB by ID (Oracle only).
*CDBsApi* | [**get_cdbs**](docs/CDBsApi.md#get_cdbs) | **GET** /cdbs | List all CDBs (Oracle only).
*CDBsApi* | [**get_tags_cdb**](docs/CDBsApi.md#get_tags_cdb) | **GET** /cdbs/{cdbId}/tags | Get tags for a CDB.
*CDBsApi* | [**search_cdbs**](docs/CDBsApi.md#search_cdbs) | **POST** /cdbs/search | Search for CDBs (Oracle only).
*ConnectivityApi* | [**connectivity_check**](docs/ConnectivityApi.md#connectivity_check) | **POST** /connectivity/check | Checks connectivity between an engine and a remote host machine on a given port.
*ConnectivityApi* | [**database_connectivity_check**](docs/ConnectivityApi.md#database_connectivity_check) | **POST** /database/connectivity/check | Tests the validity of the supplied database credentials, returning an error if unable to connect to the database.
*ConnectorsApi* | [**connectors_test**](docs/ConnectorsApi.md#connectors_test) | **POST** /connectors/{connectorId}/test | Checks connectivity between a masking engine and a remote data source.
*ConnectorsApi* | [**create_connector_tags**](docs/ConnectorsApi.md#create_connector_tags) | **POST** /connectors/{connectorId}/tags | Create tags for a Connector.
*ConnectorsApi* | [**delete_connector_tag**](docs/ConnectorsApi.md#delete_connector_tag) | **POST** /connectors/{connectorId}/tags/delete | Delete tags for a Connector.
*ConnectorsApi* | [**get_connector_by_id**](docs/ConnectorsApi.md#get_connector_by_id) | **GET** /connectors/{connectorId} | Retrieve a masking Connector by ID.
*ConnectorsApi* | [**get_connector_tags**](docs/ConnectorsApi.md#get_connector_tags) | **GET** /connectors/{connectorId}/tags | Get tags for a Connector.
*ConnectorsApi* | [**get_connectors**](docs/ConnectorsApi.md#get_connectors) | **GET** /connectors | Retrieve the list of masking connectors.
*ConnectorsApi* | [**search_connectors**](docs/ConnectorsApi.md#search_connectors) | **POST** /connectors/search | Search for masking Connectors.
*ConnectorsApi* | [**update_connector_by_id**](docs/ConnectorsApi.md#update_connector_by_id) | **PATCH** /connectors/{connectorId} | Update a masking Connector by ID.
*DSourcesApi* | [**create_tags_dsource**](docs/DSourcesApi.md#create_tags_dsource) | **POST** /dsources/{dsourceId}/tags | Create tags for a dSource.
*DSourcesApi* | [**delete_dsource**](docs/DSourcesApi.md#delete_dsource) | **POST** /dsources/delete | Delete the specified dSource.
*DSourcesApi* | [**delete_tags_dsource**](docs/DSourcesApi.md#delete_tags_dsource) | **POST** /dsources/{dsourceId}/tags/delete | Delete tags for a dSource.
*DSourcesApi* | [**disable_dsource**](docs/DSourcesApi.md#disable_dsource) | **POST** /dsources/{dsourceId}/disable | Disable a dSource.
*DSourcesApi* | [**enable_dsource**](docs/DSourcesApi.md#enable_dsource) | **POST** /dsources/{dsourceId}/enable | Enable a dSource.
*DSourcesApi* | [**get_appdata_dsource_linking_defaults**](docs/DSourcesApi.md#get_appdata_dsource_linking_defaults) | **POST** /dsources/appdata/defaults | Get defaults for an AppData dSource linking.
*DSourcesApi* | [**get_ase_dsource_linking_defaults**](docs/DSourcesApi.md#get_ase_dsource_linking_defaults) | **POST** /dsources/ase/defaults | Get defaults for an ASE dSource linking.
*DSourcesApi* | [**get_dsource_by_id**](docs/DSourcesApi.md#get_dsource_by_id) | **GET** /dsources/{dsourceId} | Get a dSource by ID.
*DSourcesApi* | [**get_dsource_snapshots**](docs/DSourcesApi.md#get_dsource_snapshots) | **GET** /dsources/{dsourceId}/snapshots | List Snapshots for a dSource.
*DSourcesApi* | [**get_dsources**](docs/DSourcesApi.md#get_dsources) | **GET** /dsources | List all dSources.
*DSourcesApi* | [**get_mssql_dsource_linking_defaults**](docs/DSourcesApi.md#get_mssql_dsource_linking_defaults) | **POST** /dsources/mssql/defaults | Get defaults for a MSSql dSource linking.
*DSourcesApi* | [**get_mssql_staging_push_dsource_linking_defaults**](docs/DSourcesApi.md#get_mssql_staging_push_dsource_linking_defaults) | **POST** /dsources/mssql/staging-push/defaults | Get defaults for a MSSql staging push dSource linking.
*DSourcesApi* | [**get_oracle_dsource_linking_defaults**](docs/DSourcesApi.md#get_oracle_dsource_linking_defaults) | **POST** /dsources/oracle/defaults | Get defaults for dSource linking.
*DSourcesApi* | [**get_oracle_staging_push_dsource_linking_defaults**](docs/DSourcesApi.md#get_oracle_staging_push_dsource_linking_defaults) | **POST** /dsources/oracle/staging-push/defaults | Get defaults for a Oracle staging push dSource linking.
*DSourcesApi* | [**get_tags_dsource**](docs/DSourcesApi.md#get_tags_dsource) | **GET** /dsources/{dsourceId}/tags | Get tags for a dSource.
*DSourcesApi* | [**link_appdata_database**](docs/DSourcesApi.md#link_appdata_database) | **POST** /dsources/appdata | Link an AppData database as dSource.
*DSourcesApi* | [**link_ase_database**](docs/DSourcesApi.md#link_ase_database) | **POST** /dsources/ase | Link an ASE database as dSource.
*DSourcesApi* | [**link_mssql_database**](docs/DSourcesApi.md#link_mssql_database) | **POST** /dsources/mssql | Link a MSSql database as dSource.
*DSourcesApi* | [**link_mssql_staging_push_database**](docs/DSourcesApi.md#link_mssql_staging_push_database) | **POST** /dsources/mssql/staging-push | Link a MSSql staging push database as dSource.
*DSourcesApi* | [**link_oracle_database**](docs/DSourcesApi.md#link_oracle_database) | **POST** /dsources/oracle | Link Oracle database as dSource.
*DSourcesApi* | [**link_oracle_staging_push_database**](docs/DSourcesApi.md#link_oracle_staging_push_database) | **POST** /dsources/oracle/staging-push | Link an Oracle staging push database as dSource.
*DSourcesApi* | [**search_dsources**](docs/DSourcesApi.md#search_dsources) | **POST** /dsources/search | Search for dSources.
*DSourcesApi* | [**snapshot_dsource**](docs/DSourcesApi.md#snapshot_dsource) | **POST** /dsources/{dsourceId}/snapshots | Snapshot a dSource.
*DatabaseTemplatesApi* | [**create_database_template**](docs/DatabaseTemplatesApi.md#create_database_template) | **POST** /database-templates | Create a database template.
*DatabaseTemplatesApi* | [**create_database_template_tags**](docs/DatabaseTemplatesApi.md#create_database_template_tags) | **POST** /database-templates/{databaseTemplateId}/tags | Create tags for a DatabaseTemplate.
*DatabaseTemplatesApi* | [**delete_database_template**](docs/DatabaseTemplatesApi.md#delete_database_template) | **DELETE** /database-templates/{databaseTemplateId} | Delete a DatabaseTemplate by ID.
*DatabaseTemplatesApi* | [**delete_database_template_tag**](docs/DatabaseTemplatesApi.md#delete_database_template_tag) | **POST** /database-templates/{databaseTemplateId}/tags/delete | Delete tags for a DatabaseTemplate.
*DatabaseTemplatesApi* | [**get_database_template_by_id**](docs/DatabaseTemplatesApi.md#get_database_template_by_id) | **GET** /database-templates/{databaseTemplateId} | Retrieve a DatabaseTemplate by ID.
*DatabaseTemplatesApi* | [**get_database_template_tags**](docs/DatabaseTemplatesApi.md#get_database_template_tags) | **GET** /database-templates/{databaseTemplateId}/tags | Get tags for a DatabaseTemplate.
*DatabaseTemplatesApi* | [**get_database_templates**](docs/DatabaseTemplatesApi.md#get_database_templates) | **GET** /database-templates | Retrieve the list of database templates.
*DatabaseTemplatesApi* | [**import_database_templates**](docs/DatabaseTemplatesApi.md#import_database_templates) | **POST** /database-templates/import | Imports the database templates from an an engine.
*DatabaseTemplatesApi* | [**search_database_templates**](docs/DatabaseTemplatesApi.md#search_database_templates) | **POST** /database-templates/search | Search DatabaseTemplates.
*DatabaseTemplatesApi* | [**undo_import_database_templates**](docs/DatabaseTemplatesApi.md#undo_import_database_templates) | **POST** /database-templates/undo-import | Undo an import of DatabaseTemplates on an Engine.
*DatabaseTemplatesApi* | [**update_database_template**](docs/DatabaseTemplatesApi.md#update_database_template) | **PATCH** /database-templates/{databaseTemplateId} | Updates a DatabaseTemplate by ID
*EnvironmentsApi* | [**compatible_repositories_by_location**](docs/EnvironmentsApi.md#compatible_repositories_by_location) | **POST** /environments/compatible_repositories_by_location | Get compatible repositories corresponding to the location.
*EnvironmentsApi* | [**compatible_repositories_by_snapshot**](docs/EnvironmentsApi.md#compatible_repositories_by_snapshot) | **POST** /environments/compatible_repositories_by_snapshot | Get compatible repositories corresponding to the snapshot.
*EnvironmentsApi* | [**compatible_repositories_by_timestamp**](docs/EnvironmentsApi.md#compatible_repositories_by_timestamp) | **POST** /environments/compatible_repositories_by_timestamp | Get compatible repositories corresponding to the timestamp.
*EnvironmentsApi* | [**compatible_repositories_from_bookmark**](docs/EnvironmentsApi.md#compatible_repositories_from_bookmark) | **POST** /environments/compatible_repositories_from_bookmark | Get compatible repositories corresponding to the bookmark.
*EnvironmentsApi* | [**create_environment**](docs/EnvironmentsApi.md#create_environment) | **POST** /environments | Create an environment.
*EnvironmentsApi* | [**create_environment_tags**](docs/EnvironmentsApi.md#create_environment_tags) | **POST** /environments/{environmentId}/tags | Create tags for an Environment.
*EnvironmentsApi* | [**create_environment_user**](docs/EnvironmentsApi.md#create_environment_user) | **POST** /environments/{environmentId}/users | Create environment user.
*EnvironmentsApi* | [**create_host**](docs/EnvironmentsApi.md#create_host) | **POST** /environments/{environmentId}/hosts | Create a new Host.
*EnvironmentsApi* | [**delete_environment**](docs/EnvironmentsApi.md#delete_environment) | **DELETE** /environments/{environmentId} | Delete an environment by ID.
*EnvironmentsApi* | [**delete_environment_tags**](docs/EnvironmentsApi.md#delete_environment_tags) | **POST** /environments/{environmentId}/tags/delete | Delete tags for an Environment.
*EnvironmentsApi* | [**delete_environment_user**](docs/EnvironmentsApi.md#delete_environment_user) | **DELETE** /environments/{environmentId}/users/{userRef} | Delete environment user.
*EnvironmentsApi* | [**delete_host**](docs/EnvironmentsApi.md#delete_host) | **DELETE** /environments/{environmentId}/hosts/{hostId} | Delete a Host.
*EnvironmentsApi* | [**disable_environment**](docs/EnvironmentsApi.md#disable_environment) | **POST** /environments/{environmentId}/disable | Disable environment.
*EnvironmentsApi* | [**enable_environment**](docs/EnvironmentsApi.md#enable_environment) | **POST** /environments/{environmentId}/enable | Enable a disabled environment.
*EnvironmentsApi* | [**get_environment_by_id**](docs/EnvironmentsApi.md#get_environment_by_id) | **GET** /environments/{environmentId} | Returns an environment by ID.
*EnvironmentsApi* | [**get_environments**](docs/EnvironmentsApi.md#get_environments) | **GET** /environments | List all environments.
*EnvironmentsApi* | [**get_tags_environment**](docs/EnvironmentsApi.md#get_tags_environment) | **GET** /environments/{environmentId}/tags | Get tags for an Environment.
*EnvironmentsApi* | [**list_environment_users**](docs/EnvironmentsApi.md#list_environment_users) | **GET** /environments/{environmentId}/users | List environment users.
*EnvironmentsApi* | [**primary_environment_user**](docs/EnvironmentsApi.md#primary_environment_user) | **POST** /environments/{environmentId}/users/{userRef}/primary | Set primary environment user.
*EnvironmentsApi* | [**refresh_environment**](docs/EnvironmentsApi.md#refresh_environment) | **POST** /environments/{environmentId}/refresh | Refresh environment.
*EnvironmentsApi* | [**search_environments**](docs/EnvironmentsApi.md#search_environments) | **POST** /environments/search | Search for environments.
*EnvironmentsApi* | [**update_environment**](docs/EnvironmentsApi.md#update_environment) | **PATCH** /environments/{environmentId} | Update an environment by ID.
*EnvironmentsApi* | [**update_environment_user**](docs/EnvironmentsApi.md#update_environment_user) | **PUT** /environments/{environmentId}/users/{userRef} | Update environment user.
*EnvironmentsApi* | [**update_host**](docs/EnvironmentsApi.md#update_host) | **PATCH** /environments/{environmentId}/hosts/{hostId} | Update a Host.
*EnvironmentsApi* | [**update_repository**](docs/EnvironmentsApi.md#update_repository) | **PATCH** /environments/{environmentId}/repository/{repositoryId} | Update a Repository.
*ExecutionsApi* | [**cancel_execution**](docs/ExecutionsApi.md#cancel_execution) | **POST** /executions/{executionId}/cancel | Cancel an Execution.
*ExecutionsApi* | [**cleanup_execution**](docs/ExecutionsApi.md#cleanup_execution) | **POST** /executions/{executionId}/cleanup | Cleanup an Execution (Hyperscale only).
*ExecutionsApi* | [**get_execution_by_id**](docs/ExecutionsApi.md#get_execution_by_id) | **GET** /executions/{executionId} | Retrieve an Execution by ID.
*ExecutionsApi* | [**get_execution_events**](docs/ExecutionsApi.md#get_execution_events) | **GET** /executions/{executionId}/events | Retrieve the list of events for a masking execution.
*ExecutionsApi* | [**get_execution_log**](docs/ExecutionsApi.md#get_execution_log) | **GET** /executions/{executionId}/log | Retrieve the masking execution log.
*ExecutionsApi* | [**get_executions**](docs/ExecutionsApi.md#get_executions) | **GET** /executions | Retrieve the list of masking executions.
*ExecutionsApi* | [**restart_execution**](docs/ExecutionsApi.md#restart_execution) | **POST** /executions/{executionId}/restart | Restart an Execution (Hyperscale only).
*ExecutionsApi* | [**search_execution_events**](docs/ExecutionsApi.md#search_execution_events) | **POST** /executions/{executionId}/events/search | Search masking executions events.
*ExecutionsApi* | [**search_executions**](docs/ExecutionsApi.md#search_executions) | **POST** /executions/search | Search masking executions.
*FeatureFlagApi* | [**get_enabled_features_flag**](docs/FeatureFlagApi.md#get_enabled_features_flag) | **GET** /enabled-features-flag | Get enabled feature flags.
*GroupsApi* | [**get_dataset_group_by_id**](docs/GroupsApi.md#get_dataset_group_by_id) | **GET** /groups/{groupId} | Get a dataset group by ID or Name.
*GroupsApi* | [**get_dataset_groups**](docs/GroupsApi.md#get_dataset_groups) | **GET** /groups | List all dataset groups.
*GroupsApi* | [**search_dataset_groups**](docs/GroupsApi.md#search_dataset_groups) | **POST** /groups/search | Search for dataset groups.
*HyperscaleInstanceApi* | [**add_engine_to_hyperscale_instance**](docs/HyperscaleInstanceApi.md#add_engine_to_hyperscale_instance) | **POST** /hyperscale-instances/{hyperscaleInstanceId}/add-engine | Add an engine to a Hyperscale Instance.
*HyperscaleInstanceApi* | [**create_hyperscale_instance_tags**](docs/HyperscaleInstanceApi.md#create_hyperscale_instance_tags) | **POST** /hyperscale-instances/{hyperscaleInstanceId}/tags | Create tags for a Hyperscale Instance.
*HyperscaleInstanceApi* | [**delete_hyperscale_instance_tags**](docs/HyperscaleInstanceApi.md#delete_hyperscale_instance_tags) | **POST** /hyperscale-instances/{hyperscaleInstanceId}/tags/delete | Delete tags for a Hyperscale Instance.
*HyperscaleInstanceApi* | [**get_hyperscale_instance_by_id**](docs/HyperscaleInstanceApi.md#get_hyperscale_instance_by_id) | **GET** /hyperscale-instances/{hyperscaleInstanceId} | Returns a Hyperscale Instance by ID.
*HyperscaleInstanceApi* | [**get_hyperscale_instance_tags**](docs/HyperscaleInstanceApi.md#get_hyperscale_instance_tags) | **GET** /hyperscale-instances/{hyperscaleInstanceId}/tags | Get tags for a Hyperscale Instance.
*HyperscaleInstanceApi* | [**get_hyperscale_instances**](docs/HyperscaleInstanceApi.md#get_hyperscale_instances) | **GET** /hyperscale-instances | Returns a list of Hyperscale instances.
*HyperscaleInstanceApi* | [**register_hyperscale_instance**](docs/HyperscaleInstanceApi.md#register_hyperscale_instance) | **POST** /hyperscale-instances | Register a Hyperscale instance
*HyperscaleInstanceApi* | [**remove_engine_from_hyperscale_instance**](docs/HyperscaleInstanceApi.md#remove_engine_from_hyperscale_instance) | **POST** /hyperscale-instances/{hyperscaleInstanceId}/remove-engine | Remove an engine from a Hyperscale Instance.
*HyperscaleInstanceApi* | [**search_hyperscale_instances**](docs/HyperscaleInstanceApi.md#search_hyperscale_instances) | **POST** /hyperscale-instances/search | Search for Hyperscale instances.
*HyperscaleInstanceApi* | [**sync_engines_hyperscale_instance**](docs/HyperscaleInstanceApi.md#sync_engines_hyperscale_instance) | **POST** /hyperscale-instances/{hyperscaleInstanceId}/sync-engines | Sync the global object from a source engine to engines on a Hyperscale Instance.
*HyperscaleInstanceApi* | [**unregister_hyperscale_instance**](docs/HyperscaleInstanceApi.md#unregister_hyperscale_instance) | **DELETE** /hyperscale-instances/{hyperscaleInstanceId} | Unregister a Hyperscale Instance.
*HyperscaleInstanceApi* | [**update_hyperscale_instance**](docs/HyperscaleInstanceApi.md#update_hyperscale_instance) | **PATCH** /hyperscale-instances/{hyperscaleInstanceId} | Update an Hyperscale Instance
*HyperscaleObjectsApi* | [**create_hyperscale_connector**](docs/HyperscaleObjectsApi.md#create_hyperscale_connector) | **POST** /hyperscale-connectors | Create a Hyperscale Connector.
*HyperscaleObjectsApi* | [**create_hyperscale_connector_tags**](docs/HyperscaleObjectsApi.md#create_hyperscale_connector_tags) | **POST** /hyperscale-connectors/{hyperscaleConnectorId}/tags | Create tags for a Hyperscale Connector.
*HyperscaleObjectsApi* | [**create_hyperscale_dataset_tags**](docs/HyperscaleObjectsApi.md#create_hyperscale_dataset_tags) | **POST** /hyperscale-datasets/{hyperscaleDatasetId}/tags | Create tags for a Hyperscale Dataset.
*HyperscaleObjectsApi* | [**create_hyperscale_mount_point**](docs/HyperscaleObjectsApi.md#create_hyperscale_mount_point) | **POST** /hyperscale-mount-points | Create a Hyperscale Mount Point
*HyperscaleObjectsApi* | [**delete_hyperscale_connector**](docs/HyperscaleObjectsApi.md#delete_hyperscale_connector) | **DELETE** /hyperscale-connectors/{hyperscaleConnectorId} | Delete a Hyperscale Connector.
*HyperscaleObjectsApi* | [**delete_hyperscale_connector_tags**](docs/HyperscaleObjectsApi.md#delete_hyperscale_connector_tags) | **POST** /hyperscale-connectors/{hyperscaleConnectorId}/tags/delete | Delete tags for a Hyperscale Connector.
*HyperscaleObjectsApi* | [**delete_hyperscale_dataset_tags**](docs/HyperscaleObjectsApi.md#delete_hyperscale_dataset_tags) | **POST** /hyperscale-datasets/{hyperscaleDatasetId}/tags/delete | Delete tags for a Hyperscale Dataset.
*HyperscaleObjectsApi* | [**delete_hyperscale_mount_point**](docs/HyperscaleObjectsApi.md#delete_hyperscale_mount_point) | **DELETE** /hyperscale-mount-points/{hyperscaleMountPointId} | Delete a Hyperscale Mount Point.
*HyperscaleObjectsApi* | [**get_hyperscale_connector_by_id**](docs/HyperscaleObjectsApi.md#get_hyperscale_connector_by_id) | **GET** /hyperscale-connectors/{hyperscaleConnectorId} | Get a Hyperscale Connector.
*HyperscaleObjectsApi* | [**get_hyperscale_connector_tags**](docs/HyperscaleObjectsApi.md#get_hyperscale_connector_tags) | **GET** /hyperscale-connectors/{hyperscaleConnectorId}/tags | Get tags for a Hyperscale Connector.
*HyperscaleObjectsApi* | [**get_hyperscale_connectors**](docs/HyperscaleObjectsApi.md#get_hyperscale_connectors) | **GET** /hyperscale-connectors | Returns a list of Hyperscale Connectors.
*HyperscaleObjectsApi* | [**get_hyperscale_dataset_by_id**](docs/HyperscaleObjectsApi.md#get_hyperscale_dataset_by_id) | **GET** /hyperscale-datasets/{hyperscaleDatasetId} | Get a Hyperscale Dataset.
*HyperscaleObjectsApi* | [**get_hyperscale_dataset_table_or_file_by_id**](docs/HyperscaleObjectsApi.md#get_hyperscale_dataset_table_or_file_by_id) | **GET** /hyperscale-datasets/{hyperscaleDatasetId}/tables-or-files/{hyperscaleDatasetTableOrFileId} | Get a Hyperscale Dataset table or file by ID.
*HyperscaleObjectsApi* | [**get_hyperscale_dataset_tables_or_files**](docs/HyperscaleObjectsApi.md#get_hyperscale_dataset_tables_or_files) | **GET** /hyperscale-datasets/{hyperscaleDatasetId}/tables-or-files | Get the tables or files of a hyperscale dataset
*HyperscaleObjectsApi* | [**get_hyperscale_dataset_tags**](docs/HyperscaleObjectsApi.md#get_hyperscale_dataset_tags) | **GET** /hyperscale-datasets/{hyperscaleDatasetId}/tags | Get tags for a Hyperscale Dataset.
*HyperscaleObjectsApi* | [**get_hyperscale_datasets**](docs/HyperscaleObjectsApi.md#get_hyperscale_datasets) | **GET** /hyperscale-datasets | Returns a list of Hyperscale Datasets.
*HyperscaleObjectsApi* | [**get_hyperscale_mount_point_by_id**](docs/HyperscaleObjectsApi.md#get_hyperscale_mount_point_by_id) | **GET** /hyperscale-mount-points/{hyperscaleMountPointId} | Get a Hyperscale Mount Points.
*HyperscaleObjectsApi* | [**get_hyperscale_mount_points**](docs/HyperscaleObjectsApi.md#get_hyperscale_mount_points) | **GET** /hyperscale-mount-points | Returns a list of Hyperscale Mount Points.
*HyperscaleObjectsApi* | [**search_hyperscale_connectors**](docs/HyperscaleObjectsApi.md#search_hyperscale_connectors) | **POST** /hyperscale-connectors/search | Search for Hyperscale Connectors.
*HyperscaleObjectsApi* | [**search_hyperscale_dataset_tables_or_files**](docs/HyperscaleObjectsApi.md#search_hyperscale_dataset_tables_or_files) | **POST** /hyperscale-datasets/{hyperscaleDatasetId}/tables-or-files/search | Search the tables or files of a hyperscale dataset
*HyperscaleObjectsApi* | [**search_hyperscale_datasets**](docs/HyperscaleObjectsApi.md#search_hyperscale_datasets) | **POST** /hyperscale-datasets/search | Search for Hyperscale Datasets.
*HyperscaleObjectsApi* | [**search_hyperscale_mount_points**](docs/HyperscaleObjectsApi.md#search_hyperscale_mount_points) | **POST** /hyperscale-mount-points/search | Search for Hyperscale Mount Points.
*HyperscaleObjectsApi* | [**update_hyperscale_connector_by_id**](docs/HyperscaleObjectsApi.md#update_hyperscale_connector_by_id) | **PATCH** /hyperscale-connectors/{hyperscaleConnectorId} | Update a Hyperscale Connector by ID.
*HyperscaleObjectsApi* | [**update_hyperscale_dataset_by_id**](docs/HyperscaleObjectsApi.md#update_hyperscale_dataset_by_id) | **PATCH** /hyperscale-datasets/{hyperscaleDatasetId} | Update a Hyperscale Dataset by ID.
*HyperscaleObjectsApi* | [**update_hyperscale_dataset_table_or_file_by_id**](docs/HyperscaleObjectsApi.md#update_hyperscale_dataset_table_or_file_by_id) | **PATCH** /hyperscale-datasets/{hyperscaleDatasetId}/tables-or-files/{hyperscaleDatasetTableOrFileId} | Update a Hyperscale Dataset table or file by ID.
*HyperscaleObjectsApi* | [**update_hyperscale_mount_point_by_id**](docs/HyperscaleObjectsApi.md#update_hyperscale_mount_point_by_id) | **PATCH** /hyperscale-mount-points/{hyperscaleMountPointId} | Update a Hyperscale Mount Point by ID.
*JobsApi* | [**abandon_job**](docs/JobsApi.md#abandon_job) | **POST** /jobs/{jobId}/abandon | Abandons a job.
*JobsApi* | [**create_job_tags**](docs/JobsApi.md#create_job_tags) | **POST** /jobs/{jobId}/tags | Create tags for a Job.
*JobsApi* | [**delete_job_tag**](docs/JobsApi.md#delete_job_tag) | **POST** /jobs/{jobId}/tags/delete | Delete tags for a Job.
*JobsApi* | [**get_job_by_id**](docs/JobsApi.md#get_job_by_id) | **GET** /jobs/{jobId} | Returns a job by ID.
*JobsApi* | [**get_job_tags**](docs/JobsApi.md#get_job_tags) | **GET** /jobs/{jobId}/tags | Get tags for a Job.
*JobsApi* | [**get_jobs**](docs/JobsApi.md#get_jobs) | **GET** /jobs | List all jobs.
*JobsApi* | [**search_jobs**](docs/JobsApi.md#search_jobs) | **POST** /jobs/search | Search for jobs.
*KerberosConfigApi* | [**get_kerberos_config_by_id**](docs/KerberosConfigApi.md#get_kerberos_config_by_id) | **GET** /kerberos-configs/{kerberosConfigId} | Get a kerberos config by ID or Name.
*KerberosConfigApi* | [**list_kerberos_configs**](docs/KerberosConfigApi.md#list_kerberos_configs) | **GET** /kerberos-configs | List all kerberos configs.
*KerberosConfigApi* | [**search_kerberos_configs**](docs/KerberosConfigApi.md#search_kerberos_configs) | **POST** /kerberos-configs/search | Search for Kerberos Configs.
*LoginApi* | [**account_login**](docs/LoginApi.md#account_login) | **POST** /login | Login to Account with Username and Password 
*LoginApi* | [**account_logout**](docs/LoginApi.md#account_logout) | **POST** /logout | Invalidates username/password and SSO login session.
*LoginApi* | [**token_info**](docs/LoginApi.md#token_info) | **POST** /token-info | Get Token Information 
*ManagementApi* | [**create_engine_tags**](docs/ManagementApi.md#create_engine_tags) | **POST** /management/engines/{engineId}/tags | Create tags for an Engine.
*ManagementApi* | [**create_hashicorp_vault**](docs/ManagementApi.md#create_hashicorp_vault) | **POST** /management/vaults/hashicorp | Configure a new Hashicorp Vault
*ManagementApi* | [**create_hashicorp_vault_tags**](docs/ManagementApi.md#create_hashicorp_vault_tags) | **POST** /management/vaults/hashicorp/{vaultId}/tags | Create tags for a Hashicorp vault.
*ManagementApi* | [**delete_engine_tags**](docs/ManagementApi.md#delete_engine_tags) | **POST** /management/engines/{engineId}/tags/delete | Delete tags for an Engine.
*ManagementApi* | [**delete_hashicorp_vault**](docs/ManagementApi.md#delete_hashicorp_vault) | **DELETE** /management/vaults/hashicorp/{vaultId} | Delete a Hashicorp vault by id
*ManagementApi* | [**delete_hashicorp_vault_tag**](docs/ManagementApi.md#delete_hashicorp_vault_tag) | **POST** /management/vaults/hashicorp/{vaultId}/tags/delete | Delete tags for a Hashicorp vault.
*ManagementApi* | [**get_api_classification**](docs/ManagementApi.md#get_api_classification) | **GET** /management/api-classification | Get api classification.
*ManagementApi* | [**get_engine_tags**](docs/ManagementApi.md#get_engine_tags) | **GET** /management/engines/{engineId}/tags | Get tags for a Engine.
*ManagementApi* | [**get_hashicorp_vault**](docs/ManagementApi.md#get_hashicorp_vault) | **GET** /management/vaults/hashicorp/{vaultId} | Get a Hashicorp vault by id
*ManagementApi* | [**get_hashicorp_vault_tags**](docs/ManagementApi.md#get_hashicorp_vault_tags) | **GET** /management/vaults/hashicorp/{vaultId}/tags | Get tags for a Hashicorp vault.
*ManagementApi* | [**get_hashicorp_vaults**](docs/ManagementApi.md#get_hashicorp_vaults) | **GET** /management/vaults/hashicorp | Returns a list of configured Hashicorp vaults.
*ManagementApi* | [**get_ldap_config**](docs/ManagementApi.md#get_ldap_config) | **GET** /management/ldap-config | Returns the LDAP configuration
*ManagementApi* | [**get_metadata_database**](docs/ManagementApi.md#get_metadata_database) | **GET** /management/metadata-database | Returns configuration information about the metadata database which stores the product data.
*ManagementApi* | [**get_product_registration_key**](docs/ManagementApi.md#get_product_registration_key) | **GET** /management/product-registration-offline | Generates and returns a public key that can be used to register the product.
*ManagementApi* | [**get_proxy_configuration**](docs/ManagementApi.md#get_proxy_configuration) | **GET** /management/proxy | Returns the current Proxy configuration.
*ManagementApi* | [**get_registered_engine**](docs/ManagementApi.md#get_registered_engine) | **GET** /management/engines/{engineId} | Returns a registered engine by ID.
*ManagementApi* | [**get_registered_engines**](docs/ManagementApi.md#get_registered_engines) | **GET** /management/engines | Returns a list of registered engines.
*ManagementApi* | [**get_saml_config**](docs/ManagementApi.md#get_saml_config) | **GET** /management/saml-config | Returns the SAML configuration
*ManagementApi* | [**get_smtp_config**](docs/ManagementApi.md#get_smtp_config) | **GET** /management/smtp | Returns the SMTP configuration
*ManagementApi* | [**list_properties**](docs/ManagementApi.md#list_properties) | **GET** /management/properties | Get global properties.
*ManagementApi* | [**register_engine**](docs/ManagementApi.md#register_engine) | **POST** /management/engines | Register an engine.
*ManagementApi* | [**register_product_offline**](docs/ManagementApi.md#register_product_offline) | **POST** /management/product-registration-offline | Registers the product using a manually generated payload.
*ManagementApi* | [**register_product_online**](docs/ManagementApi.md#register_product_online) | **POST** /management/product-registration-online | Registers the product using the provided credentials.
*ManagementApi* | [**search_engines**](docs/ManagementApi.md#search_engines) | **POST** /management/engines/search | Search for engines.
*ManagementApi* | [**search_hashicorp_vaults**](docs/ManagementApi.md#search_hashicorp_vaults) | **POST** /management/vaults/hashicorp/search | Search for configured Hashicorp vaults.
*ManagementApi* | [**unregister_engine**](docs/ManagementApi.md#unregister_engine) | **DELETE** /management/engines/{engineId} | Unregister an engine.
*ManagementApi* | [**update_api_classification**](docs/ManagementApi.md#update_api_classification) | **PUT** /management/api-classification | Update the api classification to new version.
*ManagementApi* | [**update_ldap_config**](docs/ManagementApi.md#update_ldap_config) | **PUT** /management/ldap-config | Update LDAP Config.
*ManagementApi* | [**update_properties**](docs/ManagementApi.md#update_properties) | **PATCH** /management/properties | Update value of predefined properties.
*ManagementApi* | [**update_proxy_configuration**](docs/ManagementApi.md#update_proxy_configuration) | **PUT** /management/proxy | Update Proxy configuration.
*ManagementApi* | [**update_registered_engine**](docs/ManagementApi.md#update_registered_engine) | **PUT** /management/engines/{engineId} | Update a registered engine.
*ManagementApi* | [**update_registered_engine_partial**](docs/ManagementApi.md#update_registered_engine_partial) | **PATCH** /management/engines/{engineId} | Update a registered engine.
*ManagementApi* | [**update_saml_config**](docs/ManagementApi.md#update_saml_config) | **PUT** /management/saml-config | Update SAML Config.
*ManagementApi* | [**update_smtp_config**](docs/ManagementApi.md#update_smtp_config) | **PUT** /management/smtp | Update SMTP Config.
*ManagementApi* | [**validate_java_path**](docs/ManagementApi.md#validate_java_path) | **POST** /management/engines/{engineId}/validate/java-path | Validate java path for the remote host machine.
*ManagementApi* | [**validate_ldap_config**](docs/ManagementApi.md#validate_ldap_config) | **POST** /management/ldap-config/validate | Validate LDAP Config. Without username/password, DCT performs an anonymous bind against the LDAP server. If credentials are provided DCT validates that authentication and mapping of optional properties are actually working with provided credentials. LDAP search is only validated if search attributes are set.
*ManagementApi* | [**validate_smtp_config**](docs/ManagementApi.md#validate_smtp_config) | **POST** /management/smtp/validate | Validate SMTP Config.
*MaskingEnvironmentsApi* | [**get_masking_environment_by_id**](docs/MaskingEnvironmentsApi.md#get_masking_environment_by_id) | **GET** /masking-environments/{maskingEnvironmentId} | Retrieve a MaskingEnvironment by ID.
*MaskingEnvironmentsApi* | [**get_masking_environments**](docs/MaskingEnvironmentsApi.md#get_masking_environments) | **GET** /masking-environments | Retrieve the list of masking environments.
*MaskingEnvironmentsApi* | [**search_masking_environments**](docs/MaskingEnvironmentsApi.md#search_masking_environments) | **POST** /masking-environments/search | Search masking environments.
*MaskingFilesApi* | [**upload_masking_file**](docs/MaskingFilesApi.md#upload_masking_file) | **POST** /masking-file-uploads | Upload a file for masking.
*MaskingJobsApi* | [**add_engine_to_masking_job**](docs/MaskingJobsApi.md#add_engine_to_masking_job) | **POST** /masking-jobs/{maskingJobId}/add-engine | Add an engine to a Masking Job (Hyperscale Job only).
*MaskingJobsApi* | [**copy_masking_job**](docs/MaskingJobsApi.md#copy_masking_job) | **POST** /masking-jobs/{maskingJobId}/copy | Copies the masking job to another engine.
*MaskingJobsApi* | [**create_masking_job**](docs/MaskingJobsApi.md#create_masking_job) | **POST** /masking-jobs | Create a Masking Job.
*MaskingJobsApi* | [**create_masking_job_tag**](docs/MaskingJobsApi.md#create_masking_job_tag) | **POST** /masking-jobs/{maskingJobId}/tags | Create tags for a Masking Job.
*MaskingJobsApi* | [**delete_masking_job**](docs/MaskingJobsApi.md#delete_masking_job) | **DELETE** /masking-jobs/{maskingJobId} | Delete a masking job.
*MaskingJobsApi* | [**delete_masking_job_tag**](docs/MaskingJobsApi.md#delete_masking_job_tag) | **POST** /masking-jobs/{maskingJobId}/tags/delete | Delete tags for a Masking Job.
*MaskingJobsApi* | [**execute_masking_job**](docs/MaskingJobsApi.md#execute_masking_job) | **POST** /masking-jobs/{maskingJobId}/execute | Execute a MaskingJob.
*MaskingJobsApi* | [**get_masking_job_by_id**](docs/MaskingJobsApi.md#get_masking_job_by_id) | **GET** /masking-jobs/{maskingJobId} | Retrieve a MaskingJob by ID.
*MaskingJobsApi* | [**get_masking_job_connectors**](docs/MaskingJobsApi.md#get_masking_job_connectors) | **GET** /masking-jobs/{maskingJobId}/connectors | Get connectors for a Masking Job by ID.
*MaskingJobsApi* | [**get_masking_job_source_engines**](docs/MaskingJobsApi.md#get_masking_job_source_engines) | **GET** /masking-jobs/source-engines | Retrieve the list of masking jobs along with their source engine.
*MaskingJobsApi* | [**get_masking_job_tag**](docs/MaskingJobsApi.md#get_masking_job_tag) | **GET** /masking-jobs/{maskingJobId}/tags | Get tags for a Masking Job.
*MaskingJobsApi* | [**get_masking_jobs**](docs/MaskingJobsApi.md#get_masking_jobs) | **GET** /masking-jobs | Retrieve the list of masking jobs.
*MaskingJobsApi* | [**migrate_masking_job**](docs/MaskingJobsApi.md#migrate_masking_job) | **POST** /masking-jobs/{maskingJobId}/migrate | Migrates the masking job from its current source engine to another engine.
*MaskingJobsApi* | [**re_import_masking_job**](docs/MaskingJobsApi.md#re_import_masking_job) | **POST** /masking-jobs/{maskingJobId}/re-import | Re-import the dataset from the source MaskingJob (Hyperscale Job only).
*MaskingJobsApi* | [**remove_engine_from_masking_job**](docs/MaskingJobsApi.md#remove_engine_from_masking_job) | **POST** /masking-jobs/{maskingJobId}/remove-engine | Remove an engine from a Masking Job (Hyperscale Job only).
*MaskingJobsApi* | [**search_masking_job_source_engines**](docs/MaskingJobsApi.md#search_masking_job_source_engines) | **POST** /masking-jobs/source-engines/search | Search the list of masking jobs along with their source engine.
*MaskingJobsApi* | [**search_masking_jobs**](docs/MaskingJobsApi.md#search_masking_jobs) | **POST** /masking-jobs/search | Search masking jobs.
*MaskingJobsApi* | [**update_masking_job_by_id**](docs/MaskingJobsApi.md#update_masking_job_by_id) | **PATCH** /masking-jobs/{maskingJobId} | Update values of a MaskingJob.
*MaskingPluginsApi* | [**create_masking_plugin_tags**](docs/MaskingPluginsApi.md#create_masking_plugin_tags) | **POST** /masking-plugins/{maskingPluginId}/tags | Create tags for a masking plugin.
*MaskingPluginsApi* | [**delete_masking_plugin**](docs/MaskingPluginsApi.md#delete_masking_plugin) | **DELETE** /masking-plugins/{maskingPluginId} | Delete a custom masking plugin.
*MaskingPluginsApi* | [**delete_masking_plugin_tags**](docs/MaskingPluginsApi.md#delete_masking_plugin_tags) | **POST** /masking-plugins/{maskingPluginId}/tags/delete | Delete tags for a masking plugin.
*MaskingPluginsApi* | [**get_masking_plugin_by_id**](docs/MaskingPluginsApi.md#get_masking_plugin_by_id) | **GET** /masking-plugins/{maskingPluginId} | Get a masking plugin by ID or name.
*MaskingPluginsApi* | [**get_masking_plugin_tags**](docs/MaskingPluginsApi.md#get_masking_plugin_tags) | **GET** /masking-plugins/{maskingPluginId}/tags | Get tags for a masking plugin.
*MaskingPluginsApi* | [**get_masking_plugins**](docs/MaskingPluginsApi.md#get_masking_plugins) | **GET** /masking-plugins | Retrieve the list of masking plugins.
*MaskingPluginsApi* | [**install_masking_plugin**](docs/MaskingPluginsApi.md#install_masking_plugin) | **POST** /masking-plugins | Install a custom masking plugin.
*MaskingPluginsApi* | [**search_masking_plugins**](docs/MaskingPluginsApi.md#search_masking_plugins) | **POST** /masking-plugins/search | Search for masking plugins.
*PasswordVaultsApi* | [**get_password_vault_by_id**](docs/PasswordVaultsApi.md#get_password_vault_by_id) | **GET** /password_vaults/{passwordVaultId} | Get a password vault by ID or Name.
*PasswordVaultsApi* | [**get_password_vaults**](docs/PasswordVaultsApi.md#get_password_vaults) | **GET** /password_vaults | List all password vaults.
*PasswordVaultsApi* | [**search_password_vaults**](docs/PasswordVaultsApi.md#search_password_vaults) | **POST** /password_vaults/search | Search for Password Vaults.
*ReplicationApi* | [**create_replication_profile_tags**](docs/ReplicationApi.md#create_replication_profile_tags) | **POST** /replication-profiles/{replicationProfileId}/tags | Create tags for a ReplicationProfile.
*ReplicationApi* | [**delete_repliation_profile_tags**](docs/ReplicationApi.md#delete_repliation_profile_tags) | **POST** /replication-profiles/{replicationProfileId}/tags/delete | Delete tags for a ReplicationProfile.
*ReplicationApi* | [**disable_tag_replication**](docs/ReplicationApi.md#disable_tag_replication) | **POST** /replication-profiles/{replicationProfileId}/disable-tag-replication | Disable tag replication for given ReplicationProfile.
*ReplicationApi* | [**enable_tag_replication**](docs/ReplicationApi.md#enable_tag_replication) | **POST** /replication-profiles/{replicationProfileId}/enable-tag-replication | Enable tag replication for given ReplicationProfile.
*ReplicationApi* | [**get_replication_profile_by_id**](docs/ReplicationApi.md#get_replication_profile_by_id) | **GET** /replication-profiles/{replicationProfileId} | Get a ReplicationProfile by ID.
*ReplicationApi* | [**get_replication_profile_tags**](docs/ReplicationApi.md#get_replication_profile_tags) | **GET** /replication-profiles/{replicationProfileId}/tags | Get tags for a ReplicationProfile.
*ReplicationApi* | [**get_replication_profiles**](docs/ReplicationApi.md#get_replication_profiles) | **GET** /replication-profiles | List all ReplicationProfiles.
*ReplicationApi* | [**search_replication_profiles**](docs/ReplicationApi.md#search_replication_profiles) | **POST** /replication-profiles/search | Search for ReplicationProfiles.
*ReportingApi* | [**create_reporting_schedule**](docs/ReportingApi.md#create_reporting_schedule) | **POST** /reporting/schedule | Create a new report schedule.
*ReportingApi* | [**create_reporting_schedule_tags**](docs/ReportingApi.md#create_reporting_schedule_tags) | **POST** /reporting/schedule/{reportId}/tags | Create tags for a report schedule.
*ReportingApi* | [**delete_reporting_schedule**](docs/ReportingApi.md#delete_reporting_schedule) | **DELETE** /reporting/schedule/{reportId} | Delete report schedule by ID.
*ReportingApi* | [**delete_reporting_schedule_tag**](docs/ReportingApi.md#delete_reporting_schedule_tag) | **POST** /reporting/schedule/{reportId}/tags/delete | Delete tags for a report schedule.
*ReportingApi* | [**get_api_usage_report**](docs/ReportingApi.md#get_api_usage_report) | **GET** /reporting/api-usage-report | Gets the report of API usage metrics over a given time period. This API returns at the most 10000 results in the response to protect against the server running out of memory. Users might not hit this limit with the default report without any &#39;apiUsageReportGroupByParam&#39; param but can hit this limit if the groupBy is by too granular like by &#39;client_name&#39; or &#39;user_agent&#39; only. Hence it is advisable to use startDate and endDate to &#39;limit&#39; the scope of the report.
*ReportingApi* | [**get_audit_logs_summary_report**](docs/ReportingApi.md#get_audit_logs_summary_report) | **GET** /reporting/audit-logs-summary-report | Gets the audit log summary report.
*ReportingApi* | [**get_dsource_consumption_report**](docs/ReportingApi.md#get_dsource_consumption_report) | **GET** /reporting/dsource-consumption-report | Gets the consumption report for virtualization engine dSources.
*ReportingApi* | [**get_dsource_usage_report**](docs/ReportingApi.md#get_dsource_usage_report) | **GET** /reporting/dsource-usage-report | Gets the usage report for virtualization engine dSources.
*ReportingApi* | [**get_engine_performance_analytics_report**](docs/ReportingApi.md#get_engine_performance_analytics_report) | **GET** /reporting/engine-performance-analytic-report | Gets the performance analytics report for engines.
*ReportingApi* | [**get_masking_execution_metrics_report**](docs/ReportingApi.md#get_masking_execution_metrics_report) | **GET** /reporting/masking-execution-metrics | Get the masking execution metrics report.
*ReportingApi* | [**get_product_info**](docs/ReportingApi.md#get_product_info) | **GET** /reporting/product_info | Returns the DCT Product Information.
*ReportingApi* | [**get_reporting_schedule_by_id**](docs/ReportingApi.md#get_reporting_schedule_by_id) | **GET** /reporting/schedule/{reportId} | Returns a report schedule by ID.
*ReportingApi* | [**get_reporting_schedule_tags**](docs/ReportingApi.md#get_reporting_schedule_tags) | **GET** /reporting/schedule/{reportId}/tags | Get tags for a report schedule.
*ReportingApi* | [**get_reporting_schedules**](docs/ReportingApi.md#get_reporting_schedules) | **GET** /reporting/schedule | List all report schedules.
*ReportingApi* | [**get_vdb_inventory_report**](docs/ReportingApi.md#get_vdb_inventory_report) | **GET** /reporting/vdb-inventory-report | Gets the inventory report for virtualization engine VDBs.
*ReportingApi* | [**get_virtualization_storage_summary_report**](docs/ReportingApi.md#get_virtualization_storage_summary_report) | **GET** /reporting/virtualization-storage-summary-report | Gets the storage summary report for virtualization engines.
*ReportingApi* | [**search_dsource_consumption_report**](docs/ReportingApi.md#search_dsource_consumption_report) | **POST** /reporting/dsource-consumption-report/search | Search the consumption report for virtualization engine DSources.
*ReportingApi* | [**search_dsource_usage_report**](docs/ReportingApi.md#search_dsource_usage_report) | **POST** /reporting/dsource-usage-report/search | Search the usage report for virtualization engine dSources.
*ReportingApi* | [**search_engine_performance_analytic_trends**](docs/ReportingApi.md#search_engine_performance_analytic_trends) | **POST** /reporting/engine-performance-analytic-trends/search | Search the performance analytic trend data for engines.
*ReportingApi* | [**search_engine_performance_analytics_report**](docs/ReportingApi.md#search_engine_performance_analytics_report) | **POST** /reporting/engine-performance-analytic-report/search | Search the performance analytic report for engines.
*ReportingApi* | [**search_masking_execution_metrics_report**](docs/ReportingApi.md#search_masking_execution_metrics_report) | **POST** /reporting/masking-execution-metrics/search | Search the Masking execution metrics report.
*ReportingApi* | [**search_reporting_schedules**](docs/ReportingApi.md#search_reporting_schedules) | **POST** /reporting/schedule/search | Search for report schedules.
*ReportingApi* | [**search_storage_savings_summary_report**](docs/ReportingApi.md#search_storage_savings_summary_report) | **POST** /reporting/storage-savings-report/search | Search the saving storage summary report for virtualization engines.
*ReportingApi* | [**search_vdb_inventory_report**](docs/ReportingApi.md#search_vdb_inventory_report) | **POST** /reporting/vdb-inventory-report/search | Search the inventory report for virtualization engine VDBs.
*ReportingApi* | [**search_virtualization_storage_summary_report**](docs/ReportingApi.md#search_virtualization_storage_summary_report) | **POST** /reporting/virtualization-storage-summary-report/search | Search the storage summary report for virtualization engines.
*ReportingApi* | [**update_reporting_schedule**](docs/ReportingApi.md#update_reporting_schedule) | **PUT** /reporting/schedule/{reportId} | Update a reporting schedule by ID.
*SamlLoginApi* | [**check_saml**](docs/SamlLoginApi.md#check_saml) | **GET** /is-saml-enabled | Check if SAML is enabled 
*SnapshotsApi* | [**create_snapshot_tags**](docs/SnapshotsApi.md#create_snapshot_tags) | **POST** /snapshots/{snapshotId}/tags | Create tags for a Snapshot.
*SnapshotsApi* | [**delete_snapshot**](docs/SnapshotsApi.md#delete_snapshot) | **DELETE** /snapshots/{snapshotId} | Delete a Snapshot.
*SnapshotsApi* | [**delete_snapshot_tags**](docs/SnapshotsApi.md#delete_snapshot_tags) | **POST** /snapshots/{snapshotId}/tags/delete | Delete tags for a Snapshot.
*SnapshotsApi* | [**find_by_location**](docs/SnapshotsApi.md#find_by_location) | **GET** /snapshots/find_by_location | Get the snapshots at this location for a dataset.
*SnapshotsApi* | [**find_by_timestamp**](docs/SnapshotsApi.md#find_by_timestamp) | **GET** /snapshots/find_by_timestamp | Get the snapshots at this timestamp for a dataset.
*SnapshotsApi* | [**get_snapshot_by_id**](docs/SnapshotsApi.md#get_snapshot_by_id) | **GET** /snapshots/{snapshotId} | Get a Snapshot by ID.
*SnapshotsApi* | [**get_snapshot_tags**](docs/SnapshotsApi.md#get_snapshot_tags) | **GET** /snapshots/{snapshotId}/tags | Get tags for a Snapshot.
*SnapshotsApi* | [**get_snapshot_timeflow_range**](docs/SnapshotsApi.md#get_snapshot_timeflow_range) | **GET** /snapshots/{snapshotId}/timeflow_range | Return the provisionable timeflow range based on a specific snapshot.
*SnapshotsApi* | [**get_snapshots**](docs/SnapshotsApi.md#get_snapshots) | **GET** /snapshots | Retrieve the list of snapshots.
*SnapshotsApi* | [**search_snapshots**](docs/SnapshotsApi.md#search_snapshots) | **POST** /snapshots/search | Search snapshots.
*SnapshotsApi* | [**unset_snapshot_retention**](docs/SnapshotsApi.md#unset_snapshot_retention) | **POST** /snapshots/{snapshotId}/unset_expiration | Unset a Snapshot&#39;s expiration, removing expiration and retain_forever values for the snapshot.
*SnapshotsApi* | [**update_snapshot**](docs/SnapshotsApi.md#update_snapshot) | **PATCH** /snapshots/{snapshotId} | Update values of a Snapshot.
*SourcesApi* | [**create_source_tags**](docs/SourcesApi.md#create_source_tags) | **POST** /sources/{sourceId}/tags | Create tags for a Source.
*SourcesApi* | [**delete_source_tags**](docs/SourcesApi.md#delete_source_tags) | **POST** /sources/{sourceId}/tags/delete | Delete tags for a Source.
*SourcesApi* | [**get_source_by_id**](docs/SourcesApi.md#get_source_by_id) | **GET** /sources/{sourceId} | Get a source by ID.
*SourcesApi* | [**get_source_compatible_repo**](docs/SourcesApi.md#get_source_compatible_repo) | **GET** /sources/{sourceId}/staging_compatible_repositories | Returns a list of repositories that match the specified source.
*SourcesApi* | [**get_source_tags**](docs/SourcesApi.md#get_source_tags) | **GET** /sources/{sourceId}/tags | Get tags for a Source.
*SourcesApi* | [**get_sources**](docs/SourcesApi.md#get_sources) | **GET** /sources | List all sources.
*SourcesApi* | [**search_sources**](docs/SourcesApi.md#search_sources) | **POST** /sources/search | Search for Sources.
*StagingSourcesApi* | [**create_staging_source_tags**](docs/StagingSourcesApi.md#create_staging_source_tags) | **POST** /staging-sources/{stagingSourceId}/tags | Create tags for a Staging Source.
*StagingSourcesApi* | [**delete_staging_source_tags**](docs/StagingSourcesApi.md#delete_staging_source_tags) | **POST** /staging-sources/{stagingSourceId}/tags/delete | Delete tags for a Staging Source.
*StagingSourcesApi* | [**get_staging_source_by_id**](docs/StagingSourcesApi.md#get_staging_source_by_id) | **GET** /staging-sources/{stagingSourceId} | Get a staging source by ID.
*StagingSourcesApi* | [**get_staging_source_tags**](docs/StagingSourcesApi.md#get_staging_source_tags) | **GET** /staging-sources/{stagingSourceId}/tags | Get tags for a Staging Source.
*StagingSourcesApi* | [**get_staging_sources**](docs/StagingSourcesApi.md#get_staging_sources) | **GET** /staging-sources | List all staging sources.
*StagingSourcesApi* | [**search_staging_sources**](docs/StagingSourcesApi.md#search_staging_sources) | **POST** /staging-sources/search | Search for Staging Sources.
*TestApi* | [**enable_scale_testing**](docs/TestApi.md#enable_scale_testing) | **POST** /enable-scale-testing | This is used for performance testing to enable engine and object duplication.
*TimeflowsApi* | [**create_timeflow_tags**](docs/TimeflowsApi.md#create_timeflow_tags) | **POST** /timeflows/{timeflowId}/tags | Create tags for a Timeflow.
*TimeflowsApi* | [**delete_timeflow**](docs/TimeflowsApi.md#delete_timeflow) | **DELETE** /timeflows/{timeflowId} | Delete a timeflow.
*TimeflowsApi* | [**delete_timeflow_tags**](docs/TimeflowsApi.md#delete_timeflow_tags) | **POST** /timeflows/{timeflowId}/tags/delete | Delete tags for a Timeflow.
*TimeflowsApi* | [**get_timeflow_by_id**](docs/TimeflowsApi.md#get_timeflow_by_id) | **GET** /timeflows/{timeflowId} | Get a Timeflow by ID.
*TimeflowsApi* | [**get_timeflow_snapshot_day_range**](docs/TimeflowsApi.md#get_timeflow_snapshot_day_range) | **GET** /timeflows/{timeflowId}/timeflowSnapshotDayRange | Returns the count of TimeFlow snapshots of the Timeflow aggregated by day.
*TimeflowsApi* | [**get_timeflow_tags**](docs/TimeflowsApi.md#get_timeflow_tags) | **GET** /timeflows/{timeflowId}/tags | Get tags for a Timeflow.
*TimeflowsApi* | [**get_timeflows**](docs/TimeflowsApi.md#get_timeflows) | **GET** /timeflows | Retrieve the list of timeflows.
*TimeflowsApi* | [**search_timeflows**](docs/TimeflowsApi.md#search_timeflows) | **POST** /timeflows/search | Search timeflows.
*TimeflowsApi* | [**update_timeflow**](docs/TimeflowsApi.md#update_timeflow) | **PATCH** /timeflows/{timeflowId} | Update values of a timeflow.
*ToolkitsApi* | [**create_toolkit_tags**](docs/ToolkitsApi.md#create_toolkit_tags) | **POST** /toolkits/{toolkitId}/tags | Create tags for a toolkit.
*ToolkitsApi* | [**delete_toolkit_tags**](docs/ToolkitsApi.md#delete_toolkit_tags) | **POST** /toolkits/{toolkitId}/tags/delete | Delete tags for a Toolkit.
*ToolkitsApi* | [**get_toolkit_by_id**](docs/ToolkitsApi.md#get_toolkit_by_id) | **GET** /toolkits/{toolkitId} | Get Toolkit by ID.
*ToolkitsApi* | [**get_toolkit_tags**](docs/ToolkitsApi.md#get_toolkit_tags) | **GET** /toolkits/{toolkitId}/tags | Get tags for a Toolkit.
*ToolkitsApi* | [**get_toolkits**](docs/ToolkitsApi.md#get_toolkits) | **GET** /toolkits | List all toolkits.
*ToolkitsApi* | [**search_toolkits**](docs/ToolkitsApi.md#search_toolkits) | **POST** /toolkits/search | Search for toolkits.
*VCDBsApi* | [**create_vcdb_tags**](docs/VCDBsApi.md#create_vcdb_tags) | **POST** /vcdbs/{vcdbId}/tags | Create tags for a vCDB.
*VCDBsApi* | [**delete_vcdb_tags**](docs/VCDBsApi.md#delete_vcdb_tags) | **POST** /vcdbs/{vcdbId}/tags/delete | Delete tags for a vCDB.
*VCDBsApi* | [**get_tags_vcdb**](docs/VCDBsApi.md#get_tags_vcdb) | **GET** /vcdbs/{vcdbId}/tags | Get tags for a vCDB.
*VCDBsApi* | [**get_vcdb_by_id**](docs/VCDBsApi.md#get_vcdb_by_id) | **GET** /vcdbs/{vcdbId} | Get a CDB by ID (Oracle only).
*VCDBsApi* | [**get_vcdbs**](docs/VCDBsApi.md#get_vcdbs) | **GET** /vcdbs | List all vCDBs (Oracle only).
*VCDBsApi* | [**search_vcdbs**](docs/VCDBsApi.md#search_vcdbs) | **POST** /vcdbs/search | Search for vCDBs (Oracle only).
*VDBGroupsApi* | [**create_vdb_group**](docs/VDBGroupsApi.md#create_vdb_group) | **POST** /vdb-groups | Create a new VDBGroup.
*VDBGroupsApi* | [**create_vdb_groups_tags**](docs/VDBGroupsApi.md#create_vdb_groups_tags) | **POST** /vdb-groups/{vdbGroupId}/tags | Create tags for a VDB Group.
*VDBGroupsApi* | [**delete_vdb_group**](docs/VDBGroupsApi.md#delete_vdb_group) | **DELETE** /vdb-groups/{vdbGroupId} | Delete a VDBGoup.
*VDBGroupsApi* | [**delete_vdb_group_tags**](docs/VDBGroupsApi.md#delete_vdb_group_tags) | **POST** /vdb-groups/{vdbGroupId}/tags/delete | Delete tags for a VDB Group.
*VDBGroupsApi* | [**get_bookmarks_by_vdb_group**](docs/VDBGroupsApi.md#get_bookmarks_by_vdb_group) | **GET** /vdb-groups/{vdbGroupId}/bookmarks | List bookmarks compatible with this VDB Group.
*VDBGroupsApi* | [**get_vdb_group**](docs/VDBGroupsApi.md#get_vdb_group) | **GET** /vdb-groups/{vdbGroupId} | Get a VDBGroup by name.
*VDBGroupsApi* | [**get_vdb_group_tags**](docs/VDBGroupsApi.md#get_vdb_group_tags) | **GET** /vdb-groups/{vdbGroupId}/tags | Get tags for a VDB Group.
*VDBGroupsApi* | [**get_vdb_groups**](docs/VDBGroupsApi.md#get_vdb_groups) | **GET** /vdb-groups | List all VDBGroups.
*VDBGroupsApi* | [**lock_vdb_group**](docs/VDBGroupsApi.md#lock_vdb_group) | **POST** /vdb-groups/{vdbGroupId}/lock | Lock a VDB Group.
*VDBGroupsApi* | [**provision_vdb_group_from_bookmark**](docs/VDBGroupsApi.md#provision_vdb_group_from_bookmark) | **POST** /vdb-groups/provision_from_bookmark | Provision a new VDB Group from a Bookmark.
*VDBGroupsApi* | [**refresh_vdb_group**](docs/VDBGroupsApi.md#refresh_vdb_group) | **POST** /vdb-groups/{vdbGroupId}/refresh | Refresh a VDBGroup.
*VDBGroupsApi* | [**rollback_vdb_group**](docs/VDBGroupsApi.md#rollback_vdb_group) | **POST** /vdb-groups/{vdbGroupId}/rollback | Rollback a VDBGroup.
*VDBGroupsApi* | [**search_bookmarks_by_vdb_group**](docs/VDBGroupsApi.md#search_bookmarks_by_vdb_group) | **POST** /vdb-groups/{vdbGroupId}/bookmarks/search | Search for bookmarks compatible with this VDB Group.
*VDBGroupsApi* | [**search_vdb_groups**](docs/VDBGroupsApi.md#search_vdb_groups) | **POST** /vdb-groups/search | Search for VDB Groups.
*VDBGroupsApi* | [**unlock_vdb_group**](docs/VDBGroupsApi.md#unlock_vdb_group) | **POST** /vdb-groups/{vdbGroupId}/unlock | Unlock a VDB Group.
*VDBGroupsApi* | [**update_vdb_group_by_id**](docs/VDBGroupsApi.md#update_vdb_group_by_id) | **PATCH** /vdb-groups/{vdbGroupId} | Update values of a VDB group.
*VDBsApi* | [**create_vdb_tags**](docs/VDBsApi.md#create_vdb_tags) | **POST** /vdbs/{vdbId}/tags | Create tags for a VDB.
*VDBsApi* | [**delete_vdb**](docs/VDBsApi.md#delete_vdb) | **POST** /vdbs/{vdbId}/delete | Delete a VDB.
*VDBsApi* | [**delete_vdb_tags**](docs/VDBsApi.md#delete_vdb_tags) | **POST** /vdbs/{vdbId}/tags/delete | Delete tags for a VDB.
*VDBsApi* | [**disable_vdb**](docs/VDBsApi.md#disable_vdb) | **POST** /vdbs/{vdbId}/disable | Disable a VDB.
*VDBsApi* | [**enable_vdb**](docs/VDBsApi.md#enable_vdb) | **POST** /vdbs/{vdbId}/enable | Enable a VDB.
*VDBsApi* | [**get_bookmarks_by_vdb**](docs/VDBsApi.md#get_bookmarks_by_vdb) | **GET** /vdbs/{vdbId}/bookmarks | List Bookmarks compatible with this VDB.
*VDBsApi* | [**get_tags_vdb**](docs/VDBsApi.md#get_tags_vdb) | **GET** /vdbs/{vdbId}/tags | Get tags for a VDB.
*VDBsApi* | [**get_vdb_by_id**](docs/VDBsApi.md#get_vdb_by_id) | **GET** /vdbs/{vdbId} | Get a VDB by ID.
*VDBsApi* | [**get_vdb_snapshots**](docs/VDBsApi.md#get_vdb_snapshots) | **GET** /vdbs/{vdbId}/snapshots | List Snapshots for a VDB.
*VDBsApi* | [**get_vdbs**](docs/VDBsApi.md#get_vdbs) | **GET** /vdbs | List all vdbs.
*VDBsApi* | [**lock_vdb**](docs/VDBsApi.md#lock_vdb) | **POST** /vdbs/{vdbId}/lock | Lock a VDB.
*VDBsApi* | [**provision_vdb_by_location**](docs/VDBsApi.md#provision_vdb_by_location) | **POST** /vdbs/provision_by_location | Provision a new VDB by location.
*VDBsApi* | [**provision_vdb_by_location_defaults**](docs/VDBsApi.md#provision_vdb_by_location_defaults) | **POST** /vdbs/provision_by_location/defaults | Get default provision parameters for provisioning a new VDB by location.
*VDBsApi* | [**provision_vdb_by_snapshot**](docs/VDBsApi.md#provision_vdb_by_snapshot) | **POST** /vdbs/provision_by_snapshot | Provision a new VDB by snapshot.
*VDBsApi* | [**provision_vdb_by_snapshot_defaults**](docs/VDBsApi.md#provision_vdb_by_snapshot_defaults) | **POST** /vdbs/provision_by_snapshot/defaults | Get default provision parameters for provisioning a new VDB by snapshot.
*VDBsApi* | [**provision_vdb_by_timestamp**](docs/VDBsApi.md#provision_vdb_by_timestamp) | **POST** /vdbs/provision_by_timestamp | Provision a new VDB by timestamp.
*VDBsApi* | [**provision_vdb_by_timestamp_defaults**](docs/VDBsApi.md#provision_vdb_by_timestamp_defaults) | **POST** /vdbs/provision_by_timestamp/defaults | Get default provision parameters for provisioning a new VDB by timestamp.
*VDBsApi* | [**provision_vdb_from_bookmark**](docs/VDBsApi.md#provision_vdb_from_bookmark) | **POST** /vdbs/provision_from_bookmark | Provision a new VDB from a bookmark with a single VDB.
*VDBsApi* | [**provision_vdb_from_bookmark_defaults**](docs/VDBsApi.md#provision_vdb_from_bookmark_defaults) | **POST** /vdbs/provision_from_bookmark/defaults | Get default provision parameters for provisioning a new VDB from a bookmark.
*VDBsApi* | [**refresh_vdb_by_location**](docs/VDBsApi.md#refresh_vdb_by_location) | **POST** /vdbs/{vdbId}/refresh_by_location | Refresh a VDB by location.
*VDBsApi* | [**refresh_vdb_by_snapshot**](docs/VDBsApi.md#refresh_vdb_by_snapshot) | **POST** /vdbs/{vdbId}/refresh_by_snapshot | Refresh a VDB by snapshot.
*VDBsApi* | [**refresh_vdb_by_timestamp**](docs/VDBsApi.md#refresh_vdb_by_timestamp) | **POST** /vdbs/{vdbId}/refresh_by_timestamp | Refresh a VDB by timestamp.
*VDBsApi* | [**refresh_vdb_from_bookmark**](docs/VDBsApi.md#refresh_vdb_from_bookmark) | **POST** /vdbs/{vdbId}/refresh_from_bookmark | Refresh a VDB from bookmark with a single VDB.
*VDBsApi* | [**rollback_vdb_by_snapshot**](docs/VDBsApi.md#rollback_vdb_by_snapshot) | **POST** /vdbs/{vdbId}/rollback_by_snapshot | Rollback a VDB by snapshot.
*VDBsApi* | [**rollback_vdb_by_timestamp**](docs/VDBsApi.md#rollback_vdb_by_timestamp) | **POST** /vdbs/{vdbId}/rollback_by_timestamp | Rollback a VDB by timestamp.
*VDBsApi* | [**rollback_vdb_from_bookmark**](docs/VDBsApi.md#rollback_vdb_from_bookmark) | **POST** /vdbs/{vdbId}/rollback_from_bookmark | Rollback a VDB from a bookmark with only the same VDB.
*VDBsApi* | [**search_bookmarks_by_vdb**](docs/VDBsApi.md#search_bookmarks_by_vdb) | **POST** /vdbs/{vdbId}/bookmarks/search | Search Bookmarks compatible with this VDB.
*VDBsApi* | [**search_vdbs**](docs/VDBsApi.md#search_vdbs) | **POST** /vdbs/search | Search for VDBs.
*VDBsApi* | [**snapshot_vdb**](docs/VDBsApi.md#snapshot_vdb) | **POST** /vdbs/{vdbId}/snapshots | Snapshot a VDB.
*VDBsApi* | [**start_vdb**](docs/VDBsApi.md#start_vdb) | **POST** /vdbs/{vdbId}/start | Start a VDB.
*VDBsApi* | [**stop_vdb**](docs/VDBsApi.md#stop_vdb) | **POST** /vdbs/{vdbId}/stop | Stop a VDB.
*VDBsApi* | [**switch_timeflow**](docs/VDBsApi.md#switch_timeflow) | **POST** /vdbs/{vdbId}/switch_timeflow | Switches the current timeflow of a VDB.
*VDBsApi* | [**unlock_vdb**](docs/VDBsApi.md#unlock_vdb) | **POST** /vdbs/{vdbId}/unlock | Unlock a VDB.
*VDBsApi* | [**update_vdb_by_id**](docs/VDBsApi.md#update_vdb_by_id) | **PATCH** /vdbs/{vdbId} | Update values of a VDB
*VirtualizationPoliciesApi* | [**get_virtualization_policy_by_id**](docs/VirtualizationPoliciesApi.md#get_virtualization_policy_by_id) | **GET** /virtualization-policies/{policyId} | Fetch a virtualization policy by Id.
*VirtualizationPoliciesApi* | [**list_virtualization_policies**](docs/VirtualizationPoliciesApi.md#list_virtualization_policies) | **GET** /virtualization-policies | Fetch a list of all virtualization policies
*VirtualizationPoliciesApi* | [**search_virtualization_policies**](docs/VirtualizationPoliciesApi.md#search_virtualization_policies) | **POST** /virtualization-policies/search | Search Virtualization Policies.


## Documentation For Models

 - [APIClassificationConfig](docs/APIClassificationConfig.md)
 - [ASEDSourceLinkSourceParameters](docs/ASEDSourceLinkSourceParameters.md)
 - [ASEDSourceLinkSourceParametersAllOf](docs/ASEDSourceLinkSourceParametersAllOf.md)
 - [AccessGroup](docs/AccessGroup.md)
 - [AccessGroupAccountIdsRequest](docs/AccessGroupAccountIdsRequest.md)
 - [AccessGroupScope](docs/AccessGroupScope.md)
 - [AccessGroupScopesRequest](docs/AccessGroupScopesRequest.md)
 - [AccessGroupUpdateParameters](docs/AccessGroupUpdateParameters.md)
 - [Account](docs/Account.md)
 - [AccountCreateParameter](docs/AccountCreateParameter.md)
 - [AccountCreateResponse](docs/AccountCreateResponse.md)
 - [AccountLoginParameter](docs/AccountLoginParameter.md)
 - [AccountUpdateParameter](docs/AccountUpdateParameter.md)
 - [AddEngineToHyperscaleResponse](docs/AddEngineToHyperscaleResponse.md)
 - [AddEngineToJobResponse](docs/AddEngineToJobResponse.md)
 - [AdditionalMountPoint](docs/AdditionalMountPoint.md)
 - [Algorithm](docs/Algorithm.md)
 - [AlgorithmCreateParameters](docs/AlgorithmCreateParameters.md)
 - [AlgorithmRevision](docs/AlgorithmRevision.md)
 - [AlgorithmRevisionCreateParameters](docs/AlgorithmRevisionCreateParameters.md)
 - [AlgorithmRevisionOriginEngine](docs/AlgorithmRevisionOriginEngine.md)
 - [AllObjectPermissionsResponse](docs/AllObjectPermissionsResponse.md)
 - [AlwaysAllowedPermission](docs/AlwaysAllowedPermission.md)
 - [AlwaysAllowedPermissionRequest](docs/AlwaysAllowedPermissionRequest.md)
 - [ApiClassificationObject](docs/ApiClassificationObject.md)
 - [ApiUsageData](docs/ApiUsageData.md)
 - [ApiUsageReportResponse](docs/ApiUsageReportResponse.md)
 - [AppDataDSourceLinkSourceParameters](docs/AppDataDSourceLinkSourceParameters.md)
 - [AppDataDSourceLinkSourceParametersAllOf](docs/AppDataDSourceLinkSourceParametersAllOf.md)
 - [AuditLogsSummary](docs/AuditLogsSummary.md)
 - [AuditLogsSummaryReportResponse](docs/AuditLogsSummaryReportResponse.md)
 - [AuditLogsSummaryTotals](docs/AuditLogsSummaryTotals.md)
 - [BaseDSourceLinkSourceParameters](docs/BaseDSourceLinkSourceParameters.md)
 - [BaseProvisionVDBParameters](docs/BaseProvisionVDBParameters.md)
 - [BaseProvisionVDBParametersAllOf](docs/BaseProvisionVDBParametersAllOf.md)
 - [Bookmark](docs/Bookmark.md)
 - [BookmarkCompatibleEnvironmentsResponse](docs/BookmarkCompatibleEnvironmentsResponse.md)
 - [BookmarkCompatibleRepositoryRequest](docs/BookmarkCompatibleRepositoryRequest.md)
 - [BookmarkCreateParameters](docs/BookmarkCreateParameters.md)
 - [CDB](docs/CDB.md)
 - [ChangePasswordParameter](docs/ChangePasswordParameter.md)
 - [CleanupExecutionResponse](docs/CleanupExecutionResponse.md)
 - [ClusterNodeInstance](docs/ClusterNodeInstance.md)
 - [ConfigSettingsStg](docs/ConfigSettingsStg.md)
 - [ConnectivityCheckParameters](docs/ConnectivityCheckParameters.md)
 - [ConnectivityCheckResponse](docs/ConnectivityCheckResponse.md)
 - [Connector](docs/Connector.md)
 - [ConnectorTestResponse](docs/ConnectorTestResponse.md)
 - [ConnectorUpdateParameters](docs/ConnectorUpdateParameters.md)
 - [CopyMaskingJobParameters](docs/CopyMaskingJobParameters.md)
 - [CopyMaskingJobResponse](docs/CopyMaskingJobResponse.md)
 - [CreateAlgorithmResponse](docs/CreateAlgorithmResponse.md)
 - [CreateAlgorithmRevisionResponse](docs/CreateAlgorithmRevisionResponse.md)
 - [CreateBookmarkResponse](docs/CreateBookmarkResponse.md)
 - [CreateDatabaseTemplateResponse](docs/CreateDatabaseTemplateResponse.md)
 - [CreateEnvironmentResponse](docs/CreateEnvironmentResponse.md)
 - [CreateEnvironmentUserResponse](docs/CreateEnvironmentUserResponse.md)
 - [CreateHostResponse](docs/CreateHostResponse.md)
 - [CreateHyperscaleConnectorResponse](docs/CreateHyperscaleConnectorResponse.md)
 - [CreateHyperscaleMountPointResponse](docs/CreateHyperscaleMountPointResponse.md)
 - [CreateMaskingJobRequest](docs/CreateMaskingJobRequest.md)
 - [CreateMaskingJobResponse](docs/CreateMaskingJobResponse.md)
 - [CreateRole](docs/CreateRole.md)
 - [CreateVDBGroupRequest](docs/CreateVDBGroupRequest.md)
 - [CreateVDBGroupResponse](docs/CreateVDBGroupResponse.md)
 - [CredentialsEnvVariable](docs/CredentialsEnvVariable.md)
 - [DSource](docs/DSource.md)
 - [DSourceConsumptionData](docs/DSourceConsumptionData.md)
 - [DSourceConsumptionReportResponse](docs/DSourceConsumptionReportResponse.md)
 - [DSourceHooks](docs/DSourceHooks.md)
 - [DSourceSnapshotParameters](docs/DSourceSnapshotParameters.md)
 - [DSourceUsageData](docs/DSourceUsageData.md)
 - [DSourceUsageReportResponse](docs/DSourceUsageReportResponse.md)
 - [DataPointByLocationParameters](docs/DataPointByLocationParameters.md)
 - [DataPointBySnapshotParameters](docs/DataPointBySnapshotParameters.md)
 - [DataPointByTimestampParameters](docs/DataPointByTimestampParameters.md)
 - [DataPointFromBookmarkParameters](docs/DataPointFromBookmarkParameters.md)
 - [DatabaseConnectivityCheckParameters](docs/DatabaseConnectivityCheckParameters.md)
 - [DatabaseTemplate](docs/DatabaseTemplate.md)
 - [DatabaseTemplateCreateParameters](docs/DatabaseTemplateCreateParameters.md)
 - [DatasetGroup](docs/DatasetGroup.md)
 - [DeleteAlgorithmResponse](docs/DeleteAlgorithmResponse.md)
 - [DeleteAlgorithmRevisionResponse](docs/DeleteAlgorithmRevisionResponse.md)
 - [DeleteDSourceRequest](docs/DeleteDSourceRequest.md)
 - [DeleteDatabaseTemplateResponse](docs/DeleteDatabaseTemplateResponse.md)
 - [DeleteEngineResponse](docs/DeleteEngineResponse.md)
 - [DeleteEnvironmentResponse](docs/DeleteEnvironmentResponse.md)
 - [DeleteEnvironmentUserResponse](docs/DeleteEnvironmentUserResponse.md)
 - [DeleteHostResponse](docs/DeleteHostResponse.md)
 - [DeleteHyperscaleConnectorResponse](docs/DeleteHyperscaleConnectorResponse.md)
 - [DeleteHyperscaleMountPointResponse](docs/DeleteHyperscaleMountPointResponse.md)
 - [DeleteMaskingJobResponse](docs/DeleteMaskingJobResponse.md)
 - [DeleteMaskingPluginResponse](docs/DeleteMaskingPluginResponse.md)
 - [DeleteScopeObjectTags](docs/DeleteScopeObjectTags.md)
 - [DeleteScopedObjectItem](docs/DeleteScopedObjectItem.md)
 - [DeleteSnapshotResponse](docs/DeleteSnapshotResponse.md)
 - [DeleteTag](docs/DeleteTag.md)
 - [DeleteTimeflowResponse](docs/DeleteTimeflowResponse.md)
 - [DeleteVDBParameters](docs/DeleteVDBParameters.md)
 - [DeleteVDBResponse](docs/DeleteVDBResponse.md)
 - [DisableDsourceParameters](docs/DisableDsourceParameters.md)
 - [DisableDsourceResponse](docs/DisableDsourceResponse.md)
 - [DisableEnvironmentResponse](docs/DisableEnvironmentResponse.md)
 - [DisableVDBParameters](docs/DisableVDBParameters.md)
 - [DisableVDBResponse](docs/DisableVDBResponse.md)
 - [Domain](docs/Domain.md)
 - [EffectiveScope](docs/EffectiveScope.md)
 - [EnableDsourceParameters](docs/EnableDsourceParameters.md)
 - [EnableDsourceResponse](docs/EnableDsourceResponse.md)
 - [EnableEnvironmentResponse](docs/EnableEnvironmentResponse.md)
 - [EnableScaleTestingRequest](docs/EnableScaleTestingRequest.md)
 - [EnableVDBParameters](docs/EnableVDBParameters.md)
 - [EnableVDBResponse](docs/EnableVDBResponse.md)
 - [Engine](docs/Engine.md)
 - [EngineIdBody](docs/EngineIdBody.md)
 - [EnginePerformanceAnalytic](docs/EnginePerformanceAnalytic.md)
 - [EnginePerformanceAnalyticReportResponse](docs/EnginePerformanceAnalyticReportResponse.md)
 - [EnginePerformanceAnalyticTrend](docs/EnginePerformanceAnalyticTrend.md)
 - [EnginePerformanceAnalyticTrendDatapoint](docs/EnginePerformanceAnalyticTrendDatapoint.md)
 - [EnginePerformanceAnalyticTrendResponse](docs/EnginePerformanceAnalyticTrendResponse.md)
 - [EngineRegistrationParameter](docs/EngineRegistrationParameter.md)
 - [Environment](docs/Environment.md)
 - [EnvironmentCreateParameters](docs/EnvironmentCreateParameters.md)
 - [EnvironmentRepository](docs/EnvironmentRepository.md)
 - [EnvironmentRepositoryAllOf](docs/EnvironmentRepositoryAllOf.md)
 - [EnvironmentUpdateParameters](docs/EnvironmentUpdateParameters.md)
 - [EnvironmentUser](docs/EnvironmentUser.md)
 - [EnvironmentUserParams](docs/EnvironmentUserParams.md)
 - [Error](docs/Error.md)
 - [ErrorResponse](docs/ErrorResponse.md)
 - [Errors](docs/Errors.md)
 - [ExecuteMaskingJobParameters](docs/ExecuteMaskingJobParameters.md)
 - [ExecuteMaskingJobResponse](docs/ExecuteMaskingJobResponse.md)
 - [Execution](docs/Execution.md)
 - [ExecutionCancelParameters](docs/ExecutionCancelParameters.md)
 - [ExecutionEvent](docs/ExecutionEvent.md)
 - [ExecutionLog](docs/ExecutionLog.md)
 - [FindByLocationResponse](docs/FindByLocationResponse.md)
 - [FindByTimestampResponse](docs/FindByTimestampResponse.md)
 - [Framework](docs/Framework.md)
 - [GlobalProperties](docs/GlobalProperties.md)
 - [HashicorpVault](docs/HashicorpVault.md)
 - [Hook](docs/Hook.md)
 - [Host](docs/Host.md)
 - [HostCreateParameters](docs/HostCreateParameters.md)
 - [HostUpdateParameters](docs/HostUpdateParameters.md)
 - [HyperscaleColumnOrField](docs/HyperscaleColumnOrField.md)
 - [HyperscaleConnector](docs/HyperscaleConnector.md)
 - [HyperscaleConnectorUpdateParameters](docs/HyperscaleConnectorUpdateParameters.md)
 - [HyperscaleDataTypeEnum](docs/HyperscaleDataTypeEnum.md)
 - [HyperscaleDataset](docs/HyperscaleDataset.md)
 - [HyperscaleDatasetTableOrFile](docs/HyperscaleDatasetTableOrFile.md)
 - [HyperscaleDatasetTableOrFileUpdateParameters](docs/HyperscaleDatasetTableOrFileUpdateParameters.md)
 - [HyperscaleDatasetUpdateParameters](docs/HyperscaleDatasetUpdateParameters.md)
 - [HyperscaleInstance](docs/HyperscaleInstance.md)
 - [HyperscaleInstanceRegistrationParameter](docs/HyperscaleInstanceRegistrationParameter.md)
 - [HyperscaleInstanceUpdateParams](docs/HyperscaleInstanceUpdateParams.md)
 - [HyperscaleMountPoint](docs/HyperscaleMountPoint.md)
 - [HyperscaleMountPointUpdateParameters](docs/HyperscaleMountPointUpdateParameters.md)
 - [HyperscaleTaskError](docs/HyperscaleTaskError.md)
 - [HyperscaleTaskEvent](docs/HyperscaleTaskEvent.md)
 - [InstallMaskingPluginParameters](docs/InstallMaskingPluginParameters.md)
 - [InstallMaskingPluginResponse](docs/InstallMaskingPluginResponse.md)
 - [Job](docs/Job.md)
 - [KDCServers](docs/KDCServers.md)
 - [KerberosConfig](docs/KerberosConfig.md)
 - [LDAPConfigParams](docs/LDAPConfigParams.md)
 - [LdapConfigValidateParameter](docs/LdapConfigValidateParameter.md)
 - [LdapValidateResponse](docs/LdapValidateResponse.md)
 - [LinkDSourceDefaultRequest](docs/LinkDSourceDefaultRequest.md)
 - [LinkDSourceResponse](docs/LinkDSourceResponse.md)
 - [LinkStagingPushDSourceDefaultRequest](docs/LinkStagingPushDSourceDefaultRequest.md)
 - [ListAccessGroupsResponse](docs/ListAccessGroupsResponse.md)
 - [ListAccountsResponse](docs/ListAccountsResponse.md)
 - [ListAlgorithmRevisionsResponse](docs/ListAlgorithmRevisionsResponse.md)
 - [ListAlgorithmsResponse](docs/ListAlgorithmsResponse.md)
 - [ListBookmarksByVDBGroupsResponse](docs/ListBookmarksByVDBGroupsResponse.md)
 - [ListBookmarksByVDBResponse](docs/ListBookmarksByVDBResponse.md)
 - [ListBookmarksResponse](docs/ListBookmarksResponse.md)
 - [ListCDBsResponse](docs/ListCDBsResponse.md)
 - [ListConnectorsResponse](docs/ListConnectorsResponse.md)
 - [ListDSourcesResponse](docs/ListDSourcesResponse.md)
 - [ListDatabaseTemplatesResponse](docs/ListDatabaseTemplatesResponse.md)
 - [ListEnvironmentUsers](docs/ListEnvironmentUsers.md)
 - [ListEnvironmentsResponse](docs/ListEnvironmentsResponse.md)
 - [ListExecutionEventsResponse](docs/ListExecutionEventsResponse.md)
 - [ListExecutionsResponse](docs/ListExecutionsResponse.md)
 - [ListGroupsResponse](docs/ListGroupsResponse.md)
 - [ListHashicorpVaultsResponse](docs/ListHashicorpVaultsResponse.md)
 - [ListHyperscaleConnectorsResponse](docs/ListHyperscaleConnectorsResponse.md)
 - [ListHyperscaleDatasetTablesOrFilesResponse](docs/ListHyperscaleDatasetTablesOrFilesResponse.md)
 - [ListHyperscaleDatasetsResponse](docs/ListHyperscaleDatasetsResponse.md)
 - [ListHyperscaleInstancesResponse](docs/ListHyperscaleInstancesResponse.md)
 - [ListHyperscaleMountPointsResponse](docs/ListHyperscaleMountPointsResponse.md)
 - [ListJobsResponse](docs/ListJobsResponse.md)
 - [ListKerberosConfigsResponse](docs/ListKerberosConfigsResponse.md)
 - [ListMaskingEnvironmentsResponse](docs/ListMaskingEnvironmentsResponse.md)
 - [ListMaskingJobSourceEnginesResponse](docs/ListMaskingJobSourceEnginesResponse.md)
 - [ListMaskingJobsResponse](docs/ListMaskingJobsResponse.md)
 - [ListMaskingPluginsResponse](docs/ListMaskingPluginsResponse.md)
 - [ListPasswordVaultsResponse](docs/ListPasswordVaultsResponse.md)
 - [ListRegisteredEnginesResponse](docs/ListRegisteredEnginesResponse.md)
 - [ListReplicationProfilesResponse](docs/ListReplicationProfilesResponse.md)
 - [ListReportingScheduleResponse](docs/ListReportingScheduleResponse.md)
 - [ListRolesResponse](docs/ListRolesResponse.md)
 - [ListSnapshotsResponse](docs/ListSnapshotsResponse.md)
 - [ListSourcesResponse](docs/ListSourcesResponse.md)
 - [ListStagingSourcesResponse](docs/ListStagingSourcesResponse.md)
 - [ListTimeflowsResponse](docs/ListTimeflowsResponse.md)
 - [ListToolkitResponse](docs/ListToolkitResponse.md)
 - [ListVCDBsResponse](docs/ListVCDBsResponse.md)
 - [ListVDBGroupsByBookmarkResponse](docs/ListVDBGroupsByBookmarkResponse.md)
 - [ListVDBGroupsResponse](docs/ListVDBGroupsResponse.md)
 - [ListVDBsResponse](docs/ListVDBsResponse.md)
 - [ListVirtualizationPoliciesResponse](docs/ListVirtualizationPoliciesResponse.md)
 - [LocationCompatibleEnvironmentsResponse](docs/LocationCompatibleEnvironmentsResponse.md)
 - [LocationCompatibleRepositoryRequest](docs/LocationCompatibleRepositoryRequest.md)
 - [LockVDBGroupParameters](docs/LockVDBGroupParameters.md)
 - [LockVDBParameters](docs/LockVDBParameters.md)
 - [LoginToken](docs/LoginToken.md)
 - [MSSQLDSourceLinkSourceParameters](docs/MSSQLDSourceLinkSourceParameters.md)
 - [MSSQLDSourceLinkSourceParametersAllOf](docs/MSSQLDSourceLinkSourceParametersAllOf.md)
 - [MSSQLDSourceStagingPushLinkSourceParameters](docs/MSSQLDSourceStagingPushLinkSourceParameters.md)
 - [MSSQLDSourceStagingPushLinkSourceParametersAllOf](docs/MSSQLDSourceStagingPushLinkSourceParametersAllOf.md)
 - [MaskingEnvironment](docs/MaskingEnvironment.md)
 - [MaskingExecutionMetrics](docs/MaskingExecutionMetrics.md)
 - [MaskingExecutionMetricsReportResponse](docs/MaskingExecutionMetricsReportResponse.md)
 - [MaskingFileUpload](docs/MaskingFileUpload.md)
 - [MaskingFileUploadResponse](docs/MaskingFileUploadResponse.md)
 - [MaskingJob](docs/MaskingJob.md)
 - [MaskingJobConnectorsResponse](docs/MaskingJobConnectorsResponse.md)
 - [MaskingJobSourceEngine](docs/MaskingJobSourceEngine.md)
 - [MaskingPlugin](docs/MaskingPlugin.md)
 - [MaskingRuleset](docs/MaskingRuleset.md)
 - [MetadataDbInfo](docs/MetadataDbInfo.md)
 - [MigrateMaskingJobParameters](docs/MigrateMaskingJobParameters.md)
 - [MigrateMaskingJobResponse](docs/MigrateMaskingJobResponse.md)
 - [NameValuePair](docs/NameValuePair.md)
 - [ObjectPermissionAccessGroups](docs/ObjectPermissionAccessGroups.md)
 - [ObjectPermissionAccount](docs/ObjectPermissionAccount.md)
 - [ObjectPermissionsResponse](docs/ObjectPermissionsResponse.md)
 - [ObjectTypeEnum](docs/ObjectTypeEnum.md)
 - [ObjectTypeProperty](docs/ObjectTypeProperty.md)
 - [OracleClusterNodeInstance](docs/OracleClusterNodeInstance.md)
 - [OracleDSourceLinkSourceParameters](docs/OracleDSourceLinkSourceParameters.md)
 - [OracleDSourceLinkSourceParametersAllOf](docs/OracleDSourceLinkSourceParametersAllOf.md)
 - [OracleLinkStagingPushDSourceDefaultRequest](docs/OracleLinkStagingPushDSourceDefaultRequest.md)
 - [OracleListener](docs/OracleListener.md)
 - [OracleRacCustomEnvFile](docs/OracleRacCustomEnvFile.md)
 - [OracleRacCustomEnvVar](docs/OracleRacCustomEnvVar.md)
 - [OracleStagingPushDSourceLinkSourceParameters](docs/OracleStagingPushDSourceLinkSourceParameters.md)
 - [OracleStagingPushDSourceLinkSourceParametersAllOf](docs/OracleStagingPushDSourceLinkSourceParametersAllOf.md)
 - [OracleVirtualIP](docs/OracleVirtualIP.md)
 - [PaginatedResponseMetadata](docs/PaginatedResponseMetadata.md)
 - [PasswordPoliciesParams](docs/PasswordPoliciesParams.md)
 - [PasswordVault](docs/PasswordVault.md)
 - [PermissionEnum](docs/PermissionEnum.md)
 - [PermissionObject](docs/PermissionObject.md)
 - [PermissionProperty](docs/PermissionProperty.md)
 - [PermissionsRequest](docs/PermissionsRequest.md)
 - [PrimaryEnvironmentUserResponse](docs/PrimaryEnvironmentUserResponse.md)
 - [ProductHistory](docs/ProductHistory.md)
 - [ProductInfo](docs/ProductInfo.md)
 - [ProductRegistrationOfflinePayload](docs/ProductRegistrationOfflinePayload.md)
 - [ProductRegistrationOnlinePayload](docs/ProductRegistrationOnlinePayload.md)
 - [ProvisionVDBByLocationDefaultsRequest](docs/ProvisionVDBByLocationDefaultsRequest.md)
 - [ProvisionVDBByLocationParameters](docs/ProvisionVDBByLocationParameters.md)
 - [ProvisionVDBByLocationParametersAllOf](docs/ProvisionVDBByLocationParametersAllOf.md)
 - [ProvisionVDBBySnapshotDefaultsRequest](docs/ProvisionVDBBySnapshotDefaultsRequest.md)
 - [ProvisionVDBBySnapshotParameters](docs/ProvisionVDBBySnapshotParameters.md)
 - [ProvisionVDBBySnapshotParametersAllOf](docs/ProvisionVDBBySnapshotParametersAllOf.md)
 - [ProvisionVDBByTimestampDefaultsRequest](docs/ProvisionVDBByTimestampDefaultsRequest.md)
 - [ProvisionVDBByTimestampParameters](docs/ProvisionVDBByTimestampParameters.md)
 - [ProvisionVDBByTimestampParametersAllOf](docs/ProvisionVDBByTimestampParametersAllOf.md)
 - [ProvisionVDBFromBookmarkDefaultsRequest](docs/ProvisionVDBFromBookmarkDefaultsRequest.md)
 - [ProvisionVDBFromBookmarkParameters](docs/ProvisionVDBFromBookmarkParameters.md)
 - [ProvisionVDBFromBookmarkParametersAllOf](docs/ProvisionVDBFromBookmarkParametersAllOf.md)
 - [ProvisionVDBGroupFromBookmarkParameters](docs/ProvisionVDBGroupFromBookmarkParameters.md)
 - [ProvisionVDBGroupFromBookmarkResponse](docs/ProvisionVDBGroupFromBookmarkResponse.md)
 - [ProvisionVDBResponse](docs/ProvisionVDBResponse.md)
 - [ProxyConfiguration](docs/ProxyConfiguration.md)
 - [ReImportMaskingJobResponse](docs/ReImportMaskingJobResponse.md)
 - [RefreshEnvironmentResponse](docs/RefreshEnvironmentResponse.md)
 - [RefreshVDBByLocationParameters](docs/RefreshVDBByLocationParameters.md)
 - [RefreshVDBByLocationResponse](docs/RefreshVDBByLocationResponse.md)
 - [RefreshVDBBySnapshotParameters](docs/RefreshVDBBySnapshotParameters.md)
 - [RefreshVDBBySnapshotResponse](docs/RefreshVDBBySnapshotResponse.md)
 - [RefreshVDBByTimestampParameters](docs/RefreshVDBByTimestampParameters.md)
 - [RefreshVDBByTimestampParametersAllOf](docs/RefreshVDBByTimestampParametersAllOf.md)
 - [RefreshVDBByTimestampResponse](docs/RefreshVDBByTimestampResponse.md)
 - [RefreshVDBFromBookmarkParameters](docs/RefreshVDBFromBookmarkParameters.md)
 - [RefreshVDBFromBookmarkResponse](docs/RefreshVDBFromBookmarkResponse.md)
 - [RefreshVDBGroupParameters](docs/RefreshVDBGroupParameters.md)
 - [RefreshVDBGroupResponse](docs/RefreshVDBGroupResponse.md)
 - [RegisteredEngine](docs/RegisteredEngine.md)
 - [RemoveEngineFromHyperscaleResponse](docs/RemoveEngineFromHyperscaleResponse.md)
 - [RemoveEngineFromJobResponse](docs/RemoveEngineFromJobResponse.md)
 - [RemoveMaskingJobParameters](docs/RemoveMaskingJobParameters.md)
 - [Replica](docs/Replica.md)
 - [ReplicationProfile](docs/ReplicationProfile.md)
 - [ReportingSchedule](docs/ReportingSchedule.md)
 - [ReportingScheduleCreateParameters](docs/ReportingScheduleCreateParameters.md)
 - [Repository](docs/Repository.md)
 - [ResetPasswordParameter](docs/ResetPasswordParameter.md)
 - [RestartExecutionResponse](docs/RestartExecutionResponse.md)
 - [Role](docs/Role.md)
 - [RoleAllOf](docs/RoleAllOf.md)
 - [RoleUpdateParameters](docs/RoleUpdateParameters.md)
 - [RollbackVDBBySnapshotParameters](docs/RollbackVDBBySnapshotParameters.md)
 - [RollbackVDBBySnapshotResponse](docs/RollbackVDBBySnapshotResponse.md)
 - [RollbackVDBByTimestampParameters](docs/RollbackVDBByTimestampParameters.md)
 - [RollbackVDBByTimestampResponse](docs/RollbackVDBByTimestampResponse.md)
 - [RollbackVDBFromBookmarkParameters](docs/RollbackVDBFromBookmarkParameters.md)
 - [RollbackVDBFromBookmarkResponse](docs/RollbackVDBFromBookmarkResponse.md)
 - [RollbackVDBGroupParameters](docs/RollbackVDBGroupParameters.md)
 - [RollbackVDBGroupResponse](docs/RollbackVDBGroupResponse.md)
 - [SAMLConfigParams](docs/SAMLConfigParams.md)
 - [SMTPConfigParams](docs/SMTPConfigParams.md)
 - [SMTPConfigValidate](docs/SMTPConfigValidate.md)
 - [SSHVerificationStrategy](docs/SSHVerificationStrategy.md)
 - [ScopeTag](docs/ScopeTag.md)
 - [ScopeTagsRequest](docs/ScopeTagsRequest.md)
 - [ScopeTagsResponse](docs/ScopeTagsResponse.md)
 - [ScopedObjectItem](docs/ScopedObjectItem.md)
 - [ScopedObjectItemsResponse](docs/ScopedObjectItemsResponse.md)
 - [ScopedObjectsRequest](docs/ScopedObjectsRequest.md)
 - [SearchAccessGroupsResponse](docs/SearchAccessGroupsResponse.md)
 - [SearchAccountsResponse](docs/SearchAccountsResponse.md)
 - [SearchAlgorithmRevisionsResponse](docs/SearchAlgorithmRevisionsResponse.md)
 - [SearchAlgorithmsResponse](docs/SearchAlgorithmsResponse.md)
 - [SearchBody](docs/SearchBody.md)
 - [SearchBookmarksByVDBGroupsResponse](docs/SearchBookmarksByVDBGroupsResponse.md)
 - [SearchBookmarksByVDBResponse](docs/SearchBookmarksByVDBResponse.md)
 - [SearchBookmarksResponse](docs/SearchBookmarksResponse.md)
 - [SearchCDBsResponse](docs/SearchCDBsResponse.md)
 - [SearchConnectorsResponse](docs/SearchConnectorsResponse.md)
 - [SearchDSourcesResponse](docs/SearchDSourcesResponse.md)
 - [SearchDatabaseTemplatesResponse](docs/SearchDatabaseTemplatesResponse.md)
 - [SearchDatasetGroupResponse](docs/SearchDatasetGroupResponse.md)
 - [SearchEnginesResponse](docs/SearchEnginesResponse.md)
 - [SearchEnvironmentsResponse](docs/SearchEnvironmentsResponse.md)
 - [SearchExecutionEventsResponse](docs/SearchExecutionEventsResponse.md)
 - [SearchExecutionsResponse](docs/SearchExecutionsResponse.md)
 - [SearchHashicorpVaultsResponse](docs/SearchHashicorpVaultsResponse.md)
 - [SearchHyperscaleConnectorsResponse](docs/SearchHyperscaleConnectorsResponse.md)
 - [SearchHyperscaleDatasetTablesOrFilesResponse](docs/SearchHyperscaleDatasetTablesOrFilesResponse.md)
 - [SearchHyperscaleDatasetsResponse](docs/SearchHyperscaleDatasetsResponse.md)
 - [SearchHyperscaleInstancesResponse](docs/SearchHyperscaleInstancesResponse.md)
 - [SearchHyperscaleMountPointsResponse](docs/SearchHyperscaleMountPointsResponse.md)
 - [SearchJobsResponse](docs/SearchJobsResponse.md)
 - [SearchKerberosConfigsResponse](docs/SearchKerberosConfigsResponse.md)
 - [SearchMaskingEnvironmentsResponse](docs/SearchMaskingEnvironmentsResponse.md)
 - [SearchMaskingJobSourceEnginesResponse](docs/SearchMaskingJobSourceEnginesResponse.md)
 - [SearchMaskingJobsResponse](docs/SearchMaskingJobsResponse.md)
 - [SearchMaskingPluginsResponse](docs/SearchMaskingPluginsResponse.md)
 - [SearchPasswordVaultResponse](docs/SearchPasswordVaultResponse.md)
 - [SearchReplicationProfilesResponse](docs/SearchReplicationProfilesResponse.md)
 - [SearchReportingScheduleResponse](docs/SearchReportingScheduleResponse.md)
 - [SearchRolesResponse](docs/SearchRolesResponse.md)
 - [SearchSnapshotsResponse](docs/SearchSnapshotsResponse.md)
 - [SearchSourcesResponse](docs/SearchSourcesResponse.md)
 - [SearchStagingSourcesResponse](docs/SearchStagingSourcesResponse.md)
 - [SearchTimeflowsResponse](docs/SearchTimeflowsResponse.md)
 - [SearchToolkitResponse](docs/SearchToolkitResponse.md)
 - [SearchVCDBsResponse](docs/SearchVCDBsResponse.md)
 - [SearchVDBGroupResponse](docs/SearchVDBGroupResponse.md)
 - [SearchVDBGroupsByBookmarkResponse](docs/SearchVDBGroupsByBookmarkResponse.md)
 - [SearchVDBsResponse](docs/SearchVDBsResponse.md)
 - [SearchVirtualizationPoliciesResponse](docs/SearchVirtualizationPoliciesResponse.md)
 - [SetAlgorithmPrimaryRevisionResponse](docs/SetAlgorithmPrimaryRevisionResponse.md)
 - [Snapshot](docs/Snapshot.md)
 - [SnapshotCompatibleEnvironmentsResponse](docs/SnapshotCompatibleEnvironmentsResponse.md)
 - [SnapshotCompatibleRepositoryRequest](docs/SnapshotCompatibleRepositoryRequest.md)
 - [SnapshotDSourceResponse](docs/SnapshotDSourceResponse.md)
 - [SnapshotDayRange](docs/SnapshotDayRange.md)
 - [SnapshotVDBResponse](docs/SnapshotVDBResponse.md)
 - [SnapshotsDayRangesResponse](docs/SnapshotsDayRangesResponse.md)
 - [Source](docs/Source.md)
 - [SourceOperation](docs/SourceOperation.md)
 - [StagingCompatibleEnvironmentsResponse](docs/StagingCompatibleEnvironmentsResponse.md)
 - [StagingSource](docs/StagingSource.md)
 - [StartVDBResponse](docs/StartVDBResponse.md)
 - [StopVDBResponse](docs/StopVDBResponse.md)
 - [StorageSavingsReportSummarizedData](docs/StorageSavingsReportSummarizedData.md)
 - [StorageSavingsSummaryData](docs/StorageSavingsSummaryData.md)
 - [StorageSavingsSummaryReportResponse](docs/StorageSavingsSummaryReportResponse.md)
 - [SwitchTimeflowParameters](docs/SwitchTimeflowParameters.md)
 - [SwitchTimeflowResponse](docs/SwitchTimeflowResponse.md)
 - [SyncEnginesHyperscaleParameters](docs/SyncEnginesHyperscaleParameters.md)
 - [SyncEnginesHyperscaleResponse](docs/SyncEnginesHyperscaleResponse.md)
 - [Tag](docs/Tag.md)
 - [TagsRequest](docs/TagsRequest.md)
 - [TagsResponse](docs/TagsResponse.md)
 - [TaskEvent](docs/TaskEvent.md)
 - [Timeflow](docs/Timeflow.md)
 - [TimeflowRange](docs/TimeflowRange.md)
 - [TimestampCompatibleEnvironmentsResponse](docs/TimestampCompatibleEnvironmentsResponse.md)
 - [TimestampCompatibleRepositoryRequest](docs/TimestampCompatibleRepositoryRequest.md)
 - [TokenInfoRequest](docs/TokenInfoRequest.md)
 - [TokenInfoResponse](docs/TokenInfoResponse.md)
 - [Toolkit](docs/Toolkit.md)
 - [UnregisterHyperscaleInstanceResponse](docs/UnregisterHyperscaleInstanceResponse.md)
 - [UnsetSnapshotRetentionResponse](docs/UnsetSnapshotRetentionResponse.md)
 - [UpdateAccessGroupScope](docs/UpdateAccessGroupScope.md)
 - [UpdateAlgorithmRevisionParameters](docs/UpdateAlgorithmRevisionParameters.md)
 - [UpdateAlgorithmRevisionResponse](docs/UpdateAlgorithmRevisionResponse.md)
 - [UpdateBookmarkParameters](docs/UpdateBookmarkParameters.md)
 - [UpdateBookmarkResponse](docs/UpdateBookmarkResponse.md)
 - [UpdateConnectorResponse](docs/UpdateConnectorResponse.md)
 - [UpdateDatabaseTemplateParameters](docs/UpdateDatabaseTemplateParameters.md)
 - [UpdateDatabaseTemplateResponse](docs/UpdateDatabaseTemplateResponse.md)
 - [UpdateEnvironmentResponse](docs/UpdateEnvironmentResponse.md)
 - [UpdateEnvironmentUserResponse](docs/UpdateEnvironmentUserResponse.md)
 - [UpdateHostResponse](docs/UpdateHostResponse.md)
 - [UpdateHyperscaleConnectorResponse](docs/UpdateHyperscaleConnectorResponse.md)
 - [UpdateHyperscaleDatasetResponse](docs/UpdateHyperscaleDatasetResponse.md)
 - [UpdateHyperscaleDatasetTableOrFileResponse](docs/UpdateHyperscaleDatasetTableOrFileResponse.md)
 - [UpdateHyperscaleMountPointResponse](docs/UpdateHyperscaleMountPointResponse.md)
 - [UpdateMaskingJobParameters](docs/UpdateMaskingJobParameters.md)
 - [UpdateRepositoryParameters](docs/UpdateRepositoryParameters.md)
 - [UpdateRepositoryResponse](docs/UpdateRepositoryResponse.md)
 - [UpdateSnapshotParameters](docs/UpdateSnapshotParameters.md)
 - [UpdateSnapshotResponse](docs/UpdateSnapshotResponse.md)
 - [UpdateTimeflowParameters](docs/UpdateTimeflowParameters.md)
 - [UpdateTimeflowResponse](docs/UpdateTimeflowResponse.md)
 - [UpdateVDBGroupParameters](docs/UpdateVDBGroupParameters.md)
 - [UpdateVDBParameters](docs/UpdateVDBParameters.md)
 - [UpdateVDBResponse](docs/UpdateVDBResponse.md)
 - [VCDB](docs/VCDB.md)
 - [VDB](docs/VDB.md)
 - [VDBGroup](docs/VDBGroup.md)
 - [VDBInventoryData](docs/VDBInventoryData.md)
 - [VDBInventoryReportResponse](docs/VDBInventoryReportResponse.md)
 - [ValidateJavaParameters](docs/ValidateJavaParameters.md)
 - [ValidateJavaResponse](docs/ValidateJavaResponse.md)
 - [VirtualDatasetHooks](docs/VirtualDatasetHooks.md)
 - [VirtualizationPolicy](docs/VirtualizationPolicy.md)
 - [VirtualizationSchedule](docs/VirtualizationSchedule.md)
 - [VirtualizationStorageSummaryData](docs/VirtualizationStorageSummaryData.md)
 - [VirtualizationStorageSummaryReportResponse](docs/VirtualizationStorageSummaryReportResponse.md)
 - [VirtualizationTask](docs/VirtualizationTask.md)
 - [VirtualizationTaskEvent](docs/VirtualizationTaskEvent.md)


## Documentation For Authorization


## ApiKeyAuth

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author

support@delphix.com


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in delphix.api.gateway.apis and delphix.api.gateway.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from delphix.api.gateway.api.default_api import DefaultApi`
- `from delphix.api.gateway.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import delphix.api.gateway
from delphix.api.gateway.apis import *
from delphix.api.gateway.models import *
```

